(function () {
/**
 * almond 0.2.0 Copyright (c) 2011, The Dojo Foundation All Rights Reserved.
 * Available via the MIT or new BSD license.
 * see: http://github.com/jrburke/almond for details
 */
//Going sloppy to avoid 'use strict' string cost, but strict practices should
//be followed.
/*jslint sloppy: true */
/*global setTimeout: false */

var requirejs, require, define;
(function (undef) {
    var main, req, makeMap, handlers,
        defined = {},
        waiting = {},
        config = {},
        defining = {},
        aps = [].slice;

    /**
     * Given a relative module name, like ./something, normalize it to
     * a real name that can be mapped to a path.
     * @param {String} name the relative name
     * @param {String} baseName a real name that the name arg is relative
     * to.
     * @returns {String} normalized name
     */
    function normalize(name, baseName) {
        var nameParts, nameSegment, mapValue, foundMap,
            foundI, foundStarMap, starI, i, j, part,
            baseParts = baseName && baseName.split("/"),
            map = config.map,
            starMap = (map && map['*']) || {};

        //Adjust any relative paths.
        if (name && name.charAt(0) === ".") {
            //If have a base name, try to normalize against it,
            //otherwise, assume it is a top-level require that will
            //be relative to baseUrl in the end.
            if (baseName) {
                //Convert baseName to array, and lop off the last part,
                //so that . matches that "directory" and not name of the baseName's
                //module. For instance, baseName of "one/two/three", maps to
                //"one/two/three.js", but we want the directory, "one/two" for
                //this normalization.
                baseParts = baseParts.slice(0, baseParts.length - 1);

                name = baseParts.concat(name.split("/"));

                //start trimDots
                for (i = 0; i < name.length; i += 1) {
                    part = name[i];
                    if (part === ".") {
                        name.splice(i, 1);
                        i -= 1;
                    } else if (part === "..") {
                        if (i === 1 && (name[2] === '..' || name[0] === '..')) {
                            //End of the line. Keep at least one non-dot
                            //path segment at the front so it can be mapped
                            //correctly to disk. Otherwise, there is likely
                            //no path mapping for a path starting with '..'.
                            //This can still fail, but catches the most reasonable
                            //uses of ..
                            break;
                        } else if (i > 0) {
                            name.splice(i - 1, 2);
                            i -= 2;
                        }
                    }
                }
                //end trimDots

                name = name.join("/");
            }
        }

        //Apply map config if available.
        if ((baseParts || starMap) && map) {
            nameParts = name.split('/');

            for (i = nameParts.length; i > 0; i -= 1) {
                nameSegment = nameParts.slice(0, i).join("/");

                if (baseParts) {
                    //Find the longest baseName segment match in the config.
                    //So, do joins on the biggest to smallest lengths of baseParts.
                    for (j = baseParts.length; j > 0; j -= 1) {
                        mapValue = map[baseParts.slice(0, j).join('/')];

                        //baseName segment has  config, find if it has one for
                        //this name.
                        if (mapValue) {
                            mapValue = mapValue[nameSegment];
                            if (mapValue) {
                                //Match, update name to the new value.
                                foundMap = mapValue;
                                foundI = i;
                                break;
                            }
                        }
                    }
                }

                if (foundMap) {
                    break;
                }

                //Check for a star map match, but just hold on to it,
                //if there is a shorter segment match later in a matching
                //config, then favor over this star map.
                if (!foundStarMap && starMap && starMap[nameSegment]) {
                    foundStarMap = starMap[nameSegment];
                    starI = i;
                }
            }

            if (!foundMap && foundStarMap) {
                foundMap = foundStarMap;
                foundI = starI;
            }

            if (foundMap) {
                nameParts.splice(0, foundI, foundMap);
                name = nameParts.join('/');
            }
        }

        return name;
    }

    function makeRequire(relName, forceSync) {
        return function () {
            //A version of a require function that passes a moduleName
            //value for items that may need to
            //look up paths relative to the moduleName
            return req.apply(undef, aps.call(arguments, 0).concat([relName, forceSync]));
        };
    }

    function makeNormalize(relName) {
        return function (name) {
            return normalize(name, relName);
        };
    }

    function makeLoad(depName) {
        return function (value) {
            defined[depName] = value;
        };
    }

    function callDep(name) {
        if (waiting.hasOwnProperty(name)) {
            var args = waiting[name];
            delete waiting[name];
            defining[name] = true;
            main.apply(undef, args);
        }

        if (!defined.hasOwnProperty(name) && !defining.hasOwnProperty(name)) {
            throw new Error('No ' + name);
        }
        return defined[name];
    }

    //Turns a plugin!resource to [plugin, resource]
    //with the plugin being undefined if the name
    //did not have a plugin prefix.
    function splitPrefix(name) {
        var prefix,
            index = name ? name.indexOf('!') : -1;
        if (index > -1) {
            prefix = name.substring(0, index);
            name = name.substring(index + 1, name.length);
        }
        return [prefix, name];
    }

    function onResourceLoad(name, defined, deps){
        if(requirejs.onResourceLoad && name){
            requirejs.onResourceLoad({defined:defined}, {id:name}, deps);
        }
    }

    /**
     * Makes a name map, normalizing the name, and using a plugin
     * for normalization if necessary. Grabs a ref to plugin
     * too, as an optimization.
     */
    makeMap = function (name, relName) {
        var plugin,
            parts = splitPrefix(name),
            prefix = parts[0];

        name = parts[1];

        if (prefix) {
            prefix = normalize(prefix, relName);
            plugin = callDep(prefix);
        }

        //Normalize according
        if (prefix) {
            if (plugin && plugin.normalize) {
                name = plugin.normalize(name, makeNormalize(relName));
            } else {
                name = normalize(name, relName);
            }
        } else {
            name = normalize(name, relName);
            parts = splitPrefix(name);
            prefix = parts[0];
            name = parts[1];
            if (prefix) {
                plugin = callDep(prefix);
            }
        }

        //Using ridiculous property names for space reasons
        return {
            f: prefix ? prefix + '!' + name : name, //fullName
            n: name,
            pr: prefix,
            p: plugin
        };
    };

    function makeConfig(name) {
        return function () {
            return (config && config.config && config.config[name]) || {};
        };
    }

    handlers = {
        require: function (name) {
            return makeRequire(name);
        },
        exports: function (name) {
            var e = defined[name];
            if (typeof e !== 'undefined') {
                return e;
            } else {
                return (defined[name] = {});
            }
        },
        module: function (name) {
            return {
                id: name,
                uri: '',
                exports: defined[name],
                config: makeConfig(name)
            };
        }
    };

    main = function (name, deps, callback, relName) {
        var cjsModule, depName, ret, map, i,
            args = [],
            usingExports;

        //Use name if no relName
        relName = relName || name;

        //Call the callback to define the module, if necessary.
        if (typeof callback === 'function') {

            //Pull out the defined dependencies and pass the ordered
            //values to the callback.
            //Default to [require, exports, module] if no deps
            deps = !deps.length && callback.length ? ['require', 'exports', 'module'] : deps;
            for (i = 0; i < deps.length; i += 1) {
                map = makeMap(deps[i], relName);
                depName = map.f;

                //Fast path CommonJS standard dependencies.
                if (depName === "require") {
                    args[i] = handlers.require(name);
                } else if (depName === "exports") {
                    //CommonJS module spec 1.1
                    args[i] = handlers.exports(name);
                    usingExports = true;
                } else if (depName === "module") {
                    //CommonJS module spec 1.1
                    cjsModule = args[i] = handlers.module(name);
                } else if (defined.hasOwnProperty(depName) ||
                           waiting.hasOwnProperty(depName) ||
                           defining.hasOwnProperty(depName)) {
                    args[i] = callDep(depName);
                } else if (map.p) {
                    map.p.load(map.n, makeRequire(relName, true), makeLoad(depName), {});
                    args[i] = defined[depName];
                } else {
                    throw new Error(name + ' missing ' + depName);
                }
            }

            ret = callback.apply(defined[name], args);

            if (name) {
                //If setting exports via "module" is in play,
                //favor that over return value and exports. After that,
                //favor a non-undefined return value over exports use.
                if (cjsModule && cjsModule.exports !== undef &&
                        cjsModule.exports !== defined[name]) {
                    defined[name] = cjsModule.exports;
                } else if (ret !== undef || !usingExports) {
                    //Use the return value from the function.
                    defined[name] = ret;
                }
            }
        } else if (name) {
            //May just be an object definition for the module. Only
            //worry about defining if have a module name.
            defined[name] = callback;
        }

        onResourceLoad(name, defined, args);
    };

    requirejs = require = req = function (deps, callback, relName, forceSync, alt) {
        if (typeof deps === "string") {
            if (handlers[deps]) {
                //callback in this case is really relName
                return handlers[deps](callback);
            }
            //Just return the module wanted. In this scenario, the
            //deps arg is the module name, and second arg (if passed)
            //is just the relName.
            //Normalize module name, if it contains . or ..
            return callDep(makeMap(deps, callback).f);
        } else if (!deps.splice) {
            //deps is a config object, not an array.
            config = deps;
            if (callback.splice) {
                //callback is an array, which means it is a dependency list.
                //Adjust args if there are dependencies
                deps = callback;
                callback = relName;
                relName = null;
            } else {
                deps = undef;
            }
        }

        //Support require(['a'])
        callback = callback || function () {};

        //If relName is a function, it is an errback handler,
        //so remove it.
        if (typeof relName === 'function') {
            relName = forceSync;
            forceSync = alt;
        }

        //Simulate async callback;
        if (forceSync) {
            main(undef, deps, callback, relName);
        } else {
            setTimeout(function () {
                main(undef, deps, callback, relName);
            }, 15);
        }

        return req;
    };

    /**
     * Just drops the config on the floor, but returns req in case
     * the config return value is used.
     */
    req.config = function (cfg) {
        config = cfg;
        return req;
    };

    define = function (name, deps, callback) {

        //This module may not have dependencies
        if (!deps.splice) {
            //deps is not an array, so probably means
            //an object literal or factory function for
            //the value. Adjust args.
            callback = deps;
            deps = [];
        }

        waiting[name] = [name, deps, callback];
    };

    define.amd = {
        jQuery: true
    };
}());

define("../Scripts/almond-custom", function(){});

define('durandal/system',["require","jquery"],function(e,t){function n(e){var t="[object "+e+"]";i["is"+e]=function(e){return s.call(e)==t}}var i,r=!1,a=Object.keys,o=Object.prototype.hasOwnProperty,s=Object.prototype.toString,c=!1,u=Array.isArray,l=Array.prototype.slice;if(Function.prototype.bind&&("object"==typeof console||"function"==typeof console)&&"object"==typeof console.log)try{["log","info","warn","error","assert","dir","clear","profile","profileEnd"].forEach(function(e){console[e]=this.call(console[e],console)},Function.prototype.bind)}catch(d){c=!0}e.on&&e.on("moduleLoaded",function(e,t){i.setModuleId(e,t)}),"undefined"!=typeof requirejs&&(requirejs.onResourceLoad=function(e,t){i.setModuleId(e.defined[t.id],t.id)});var f=function(){},v=function(){try{if("undefined"!=typeof console&&"function"==typeof console.log)if(window.opera)for(var e=0;e<arguments.length;)console.log("Item "+(e+1)+": "+arguments[e]),e++;else 1==l.call(arguments).length&&"string"==typeof l.call(arguments)[0]?console.log(l.call(arguments).toString()):console.log.apply(console,l.call(arguments));else Function.prototype.bind&&!c||"undefined"==typeof console||"object"!=typeof console.log||Function.prototype.call.call(console.log,console,l.call(arguments))}catch(t){}},g=function(e){if(e instanceof Error)throw e;throw new Error(e)};i={version:"2.0.0",noop:f,getModuleId:function(e){return e?"function"==typeof e?e.prototype.__moduleId__:"string"==typeof e?null:e.__moduleId__:null},setModuleId:function(e,t){return e?"function"==typeof e?(e.prototype.__moduleId__=t,void 0):("string"!=typeof e&&(e.__moduleId__=t),void 0):void 0},resolveObject:function(e){return i.isFunction(e)?new e:e},debug:function(e){return 1==arguments.length&&(r=e,r?(this.log=v,this.error=g,this.log("Debug:Enabled")):(this.log("Debug:Disabled"),this.log=f,this.error=f)),r},log:f,error:f,assert:function(e,t){e||i.error(new Error(t||"Assert:Failed"))},defer:function(e){return t.Deferred(e)},guid:function(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(e){var t=0|16*Math.random(),n="x"==e?t:8|3&t;return n.toString(16)})},acquire:function(){var t,n=arguments[0],r=!1;return i.isArray(n)?(t=n,r=!0):t=l.call(arguments,0),this.defer(function(n){e(t,function(){var e=arguments;setTimeout(function(){e.length>1||r?n.resolve(l.call(e,0)):n.resolve(e[0])},1)},function(e){n.reject(e)})}).promise()},extend:function(e){for(var t=l.call(arguments,1),n=0;n<t.length;n++){var i=t[n];if(i)for(var r in i)e[r]=i[r]}return e},wait:function(e){return i.defer(function(t){setTimeout(t.resolve,e)}).promise()}},i.keys=a||function(e){if(e!==Object(e))throw new TypeError("Invalid object");var t=[];for(var n in e)o.call(e,n)&&(t[t.length]=n);return t},i.isElement=function(e){return!(!e||1!==e.nodeType)},i.isArray=u||function(e){return"[object Array]"==s.call(e)},i.isObject=function(e){return e===Object(e)},i.isBoolean=function(e){return"boolean"==typeof e},i.isPromise=function(e){return e&&i.isFunction(e.then)};for(var p=["Arguments","Function","String","Number","Date","RegExp"],m=0;m<p.length;m++)n(p[m]);return i});
define('durandal/viewEngine',["durandal/system","jquery"],function(e,t){var n;return n=t.parseHTML?function(e){return t.parseHTML(e)}:function(e){return t(e).get()},{viewExtension:".html",viewPlugin:"text",isViewUrl:function(e){return-1!==e.indexOf(this.viewExtension,e.length-this.viewExtension.length)},convertViewUrlToViewId:function(e){return e.substring(0,e.length-this.viewExtension.length)},convertViewIdToRequirePath:function(e){return this.viewPlugin+"!"+e+this.viewExtension},parseMarkup:n,processMarkup:function(e){var t=this.parseMarkup(e);return this.ensureSingleElement(t)},ensureSingleElement:function(e){if(1==e.length)return e[0];for(var n=[],i=0;i<e.length;i++){var r=e[i];if(8!=r.nodeType){if(3==r.nodeType){var a=/\S/.test(r.nodeValue);if(!a)continue}n.push(r)}}return n.length>1?t(n).wrapAll('<div class="durandal-wrapper"></div>').parent().get(0):n[0]},createView:function(t){var n=this,i=this.convertViewIdToRequirePath(t);return e.defer(function(r){e.acquire(i).then(function(e){var i=n.processMarkup(e);i.setAttribute("data-view",t),r.resolve(i)}).fail(function(e){n.createFallbackView(t,i,e).then(function(e){e.setAttribute("data-view",t),r.resolve(e)})})}).promise()},createFallbackView:function(t,n){var i=this,r='View Not Found. Searched for "'+t+'" via path "'+n+'".';return e.defer(function(e){e.resolve(i.processMarkup('<div class="durandal-view-404">'+r+"</div>"))}).promise()}}});
define('durandal/viewLocator',["durandal/system","durandal/viewEngine"],function(e,t){function n(e,t){for(var n=0;n<e.length;n++){var i=e[n],r=i.getAttribute("data-view");if(r==t)return i}}function i(e){return(e+"").replace(/([\\\.\+\*\?\[\^\]\$\(\)\{\}\=\!\<\>\|\:])/g,"\\$1")}return{useConvention:function(e,t,n){e=e||"viewmodels",t=t||"views",n=n||t;var r=new RegExp(i(e),"gi");this.convertModuleIdToViewId=function(e){return e.replace(r,t)},this.translateViewIdToArea=function(e,t){return t&&"partial"!=t?n+"/"+t+"/"+e:n+"/"+e}},locateViewForObject:function(t,n,i){var r;if(t.getView&&(r=t.getView()))return this.locateView(r,n,i);if(t.viewUrl)return this.locateView(t.viewUrl,n,i);var a=e.getModuleId(t);return a?this.locateView(this.convertModuleIdToViewId(a),n,i):this.locateView(this.determineFallbackViewId(t),n,i)},convertModuleIdToViewId:function(e){return e},determineFallbackViewId:function(e){var t=/function (.{1,})\(/,n=t.exec(e.constructor.toString()),i=n&&n.length>1?n[1]:"";return"views/"+i},translateViewIdToArea:function(e){return e},locateView:function(i,r,a){if("string"==typeof i){var o;if(o=t.isViewUrl(i)?t.convertViewUrlToViewId(i):i,r&&(o=this.translateViewIdToArea(o,r)),a){var s=n(a,o);if(s)return e.defer(function(e){e.resolve(s)}).promise()}return t.createView(o)}return e.defer(function(e){e.resolve(i)}).promise()}}});
define('durandal/binder',["durandal/system","knockout"],function(t,e){function n(e){return void 0===e?{applyBindings:!0}:t.isBoolean(e)?{applyBindings:e}:(void 0===e.applyBindings&&(e.applyBindings=!0),e)}function i(i,u,l,d){if(!u||!l)return r.throwOnErrors?t.error(a):t.log(a,u,d),void 0;if(!u.getAttribute)return r.throwOnErrors?t.error(o):t.log(o,u,d),void 0;var f=u.getAttribute("data-view");try{var v;return i&&i.binding&&(v=i.binding(u)),v=n(v),r.binding(d,u,v),v.applyBindings?(t.log("Binding",f,d),e.applyBindings(l,u)):i&&e.utils.domData.set(u,c,{$data:i}),r.bindingComplete(d,u,v),i&&i.bindingComplete&&i.bindingComplete(u),e.utils.domData.set(u,s,v),v}catch(g){g.message=g.message+";\nView: "+f+";\nModuleId: "+t.getModuleId(d),r.throwOnErrors?t.error(g):t.log(g.message)}}var r,a="Insufficient Information to Bind",o="Unexpected View Type",s="durandal-binding-instruction",c="__ko_bindingContext__";return r={binding:t.noop,bindingComplete:t.noop,throwOnErrors:!1,getBindingInstruction:function(t){return e.utils.domData.get(t,s)},bindContext:function(t,e,n){return n&&t&&(t=t.createChildContext(n)),i(n,e,t,n||(t?t.$data:null))},bind:function(t,e){return i(t,e,t,t)}}});
define('durandal/activator',["durandal/system","knockout"],function(t,e){function n(t){return void 0==t&&(t={}),t.closeOnDeactivate||(t.closeOnDeactivate=u.defaults.closeOnDeactivate),t.beforeActivate||(t.beforeActivate=u.defaults.beforeActivate),t.afterDeactivate||(t.afterDeactivate=u.defaults.afterDeactivate),t.affirmations||(t.affirmations=u.defaults.affirmations),t.interpretResponse||(t.interpretResponse=u.defaults.interpretResponse),t.areSameItem||(t.areSameItem=u.defaults.areSameItem),t}function i(e,n,i){return t.isArray(i)?e[n].apply(e,i):e[n](i)}function r(e,n,i,r,a){if(e&&e.deactivate){t.log("Deactivating",e);var o;try{o=e.deactivate(n)}catch(s){return t.error(s),r.resolve(!1),void 0}o&&o.then?o.then(function(){i.afterDeactivate(e,n,a),r.resolve(!0)},function(e){t.log(e),r.resolve(!1)}):(i.afterDeactivate(e,n,a),r.resolve(!0))}else e&&i.afterDeactivate(e,n,a),r.resolve(!0)}function a(e,n,r,a){if(e)if(e.activate){t.log("Activating",e);var o;try{o=i(e,"activate",a)}catch(s){return t.error(s),r(!1),void 0}o&&o.then?o.then(function(){n(e),r(!0)},function(e){t.log(e),r(!1)}):(n(e),r(!0))}else n(e),r(!0);else r(!0)}function o(e,n,i){return i.lifecycleData=null,t.defer(function(r){if(e&&e.canDeactivate){var a;try{a=e.canDeactivate(n)}catch(o){return t.error(o),r.resolve(!1),void 0}a.then?a.then(function(t){i.lifecycleData=t,r.resolve(i.interpretResponse(t))},function(e){t.error(e),r.resolve(!1)}):(i.lifecycleData=a,r.resolve(i.interpretResponse(a)))}else r.resolve(!0)}).promise()}function s(e,n,r,a){return r.lifecycleData=null,t.defer(function(o){if(e==n())return o.resolve(!0),void 0;if(e&&e.canActivate){var s;try{s=i(e,"canActivate",a)}catch(c){return t.error(c),o.resolve(!1),void 0}s.then?s.then(function(t){r.lifecycleData=t,o.resolve(r.interpretResponse(t))},function(e){t.error(e),o.resolve(!1)}):(r.lifecycleData=s,o.resolve(r.interpretResponse(s)))}else o.resolve(!0)}).promise()}function c(i,c){var u,l=e.observable(null);c=n(c);var d=e.computed({read:function(){return l()},write:function(t){d.viaSetter=!0,d.activateItem(t)}});return d.__activator__=!0,d.settings=c,c.activator=d,d.isActivating=e.observable(!1),d.canDeactivateItem=function(t,e){return o(t,e,c)},d.deactivateItem=function(e,n){return t.defer(function(t){d.canDeactivateItem(e,n).then(function(i){i?r(e,n,c,t,l):(d.notifySubscribers(),t.resolve(!1))})}).promise()},d.canActivateItem=function(t,e){return s(t,l,c,e)},d.activateItem=function(e,n){var i=d.viaSetter;return d.viaSetter=!1,t.defer(function(o){if(d.isActivating())return o.resolve(!1),void 0;d.isActivating(!0);var s=l();return c.areSameItem(s,e,u,n)?(d.isActivating(!1),o.resolve(!0),void 0):(d.canDeactivateItem(s,c.closeOnDeactivate).then(function(f){f?d.canActivateItem(e,n).then(function(f){f?t.defer(function(t){r(s,c.closeOnDeactivate,c,t)}).promise().then(function(){e=c.beforeActivate(e,n),a(e,l,function(t){u=n,d.isActivating(!1),o.resolve(t)},n)}):(i&&d.notifySubscribers(),d.isActivating(!1),o.resolve(!1))}):(i&&d.notifySubscribers(),d.isActivating(!1),o.resolve(!1))}),void 0)}).promise()},d.canActivate=function(){var t;return i?(t=i,i=!1):t=d(),d.canActivateItem(t)},d.activate=function(){var t;return i?(t=i,i=!1):t=d(),d.activateItem(t)},d.canDeactivate=function(t){return d.canDeactivateItem(d(),t)},d.deactivate=function(t){return d.deactivateItem(d(),t)},d.includeIn=function(t){t.canActivate=function(){return d.canActivate()},t.activate=function(){return d.activate()},t.canDeactivate=function(t){return d.canDeactivate(t)},t.deactivate=function(t){return d.deactivate(t)}},c.includeIn?d.includeIn(c.includeIn):i&&d.activate(),d.forItems=function(e){c.closeOnDeactivate=!1,c.determineNextItemToActivate=function(t,e){var n=e-1;return-1==n&&t.length>1?t[1]:n>-1&&n<t.length-1?t[n]:null},c.beforeActivate=function(t){var n=d();if(t){var i=e.indexOf(t);-1==i?e.push(t):t=e()[i]}else t=c.determineNextItemToActivate(e,n?e.indexOf(n):0);return t},c.afterDeactivate=function(t,n){n&&e.remove(t)};var n=d.canDeactivate;d.canDeactivate=function(i){return i?t.defer(function(t){function n(){for(var e=0;e<a.length;e++)if(!a[e])return t.resolve(!1),void 0;t.resolve(!0)}for(var r=e(),a=[],o=0;o<r.length;o++)d.canDeactivateItem(r[o],i).then(function(t){a.push(t),a.length==r.length&&n()})}).promise():n()};var i=d.deactivate;return d.deactivate=function(n){return n?t.defer(function(t){function i(i){d.deactivateItem(i,n).then(function(){a++,e.remove(i),a==o&&t.resolve()})}for(var r=e(),a=0,o=r.length,s=0;o>s;s++)i(r[s])}).promise():i()},d},d}var u,l={closeOnDeactivate:!0,affirmations:["yes","ok","true"],interpretResponse:function(n){return t.isObject(n)&&(n=n.can||!1),t.isString(n)?-1!==e.utils.arrayIndexOf(this.affirmations,n.toLowerCase()):n},areSameItem:function(t,e){return t==e},beforeActivate:function(t){return t},afterDeactivate:function(t,e,n){e&&n&&n(null)}};return u={defaults:l,create:c,isActivator:function(t){return t&&t.__activator__}}});
define('durandal/composition',["durandal/system","durandal/viewLocator","durandal/binder","durandal/viewEngine","durandal/activator","jquery","knockout"],function(e,t,n,i,r,a,o){function s(e){for(var t=[],n={childElements:t,activeView:null},i=o.virtualElements.firstChild(e);i;)1==i.nodeType&&(t.push(i),i.getAttribute(h)&&(n.activeView=i)),i=o.virtualElements.nextSibling(i);return n.activeView||(n.activeView=t[0]),n}function c(){y--,0===y&&setTimeout(function(){for(var e=b.length;e--;)b[e]();b=[]},1)}function u(t,n,i){if(i)n();else if(t.activate&&t.model&&t.model.activate){var r;r=e.isArray(t.activationData)?t.model.activate.apply(t.model,t.activationData):t.model.activate(t.activationData),r&&r.then?r.then(n):r||void 0===r?n():c()}else n()}function l(){var t=this;t.activeView&&t.activeView.removeAttribute(h),t.child&&(t.model&&t.model.attached&&(t.composingNewView||t.alwaysTriggerAttach)&&t.model.attached(t.child,t.parent,t),t.attached&&t.attached(t.child,t.parent,t),t.child.setAttribute(h,!0),t.composingNewView&&t.model&&(t.model.compositionComplete&&p.current.complete(function(){t.model.compositionComplete(t.child,t.parent,t)}),t.model.detached&&o.utils.domNodeDisposal.addDisposeCallback(t.child,function(){t.model.detached(t.child,t.parent,t)})),t.compositionComplete&&p.current.complete(function(){t.compositionComplete(t.child,t.parent,t)})),c(),t.triggerAttach=e.noop}function d(t){if(e.isString(t.transition)){if(t.activeView){if(t.activeView==t.child)return!1;if(!t.child)return!0;if(t.skipTransitionOnSameViewId){var n=t.activeView.getAttribute("data-view"),i=t.child.getAttribute("data-view");return n!=i}}return!0}return!1}function f(e){for(var t=0,n=e.length,i=[];n>t;t++){var r=e[t].cloneNode(!0);i.push(r)}return i}function v(e){var t=f(e.parts),n=p.getParts(t),i=p.getParts(e.child);for(var r in n)a(i[r]).replaceWith(n[r])}function g(t){var n,i,r=o.virtualElements.childNodes(t);if(!e.isArray(r)){var a=[];for(n=0,i=r.length;i>n;n++)a[n]=r[n];r=a}for(n=1,i=r.length;i>n;n++)o.removeNode(r[n])}var p,m={},h="data-active-view",b=[],y=0,k="durandal-composition-data",w="data-part",x="["+w+"]",T=["model","view","transition","area","strategy","activationData"],S={complete:function(e){b.push(e)}};return p={convertTransitionToModuleId:function(e){return"transitions/"+e},defaultTransitionName:null,current:S,addBindingHandler:function(e,t,n){var i,r,a="composition-handler-"+e;t=t||o.bindingHandlers[e],n=n||function(){return void 0},r=o.bindingHandlers[e]={init:function(e,i,r,s,c){var u={trigger:o.observable(null)};return p.current.complete(function(){t.init&&t.init(e,i,r,s,c),t.update&&(o.utils.domData.set(e,a,t),u.trigger("trigger"))}),o.utils.domData.set(e,a,u),n(e,i,r,s,c)},update:function(e,t,n,i,r){var s=o.utils.domData.get(e,a);return s.update?s.update(e,t,n,i,r):(s.trigger(),void 0)}};for(i in t)"init"!==i&&"update"!==i&&(r[i]=t[i])},getParts:function(t){var n={};e.isArray(t)||(t=[t]);for(var i=0;i<t.length;i++){var r=t[i];if(r.getAttribute){var o=r.getAttribute(w);o&&(n[o]=r);for(var s=a(x,r).not(a("[data-bind] "+x,r)),c=0;c<s.length;c++){var u=s.get(c);n[u.getAttribute(w)]=u}}}return n},cloneNodes:f,finalize:function(t){if(t.transition=t.transition||this.defaultTransitionName,t.child||t.activeView)if(d(t)){var i=this.convertTransitionToModuleId(t.transition);e.acquire(i).then(function(e){t.transition=e,e(t).then(function(){if(t.cacheViews){if(t.activeView){var e=n.getBindingInstruction(t.activeView);void 0==e.cacheViews||e.cacheViews||o.removeNode(t.activeView)}}else t.child?g(t.parent):o.virtualElements.emptyNode(t.parent);t.triggerAttach()})}).fail(function(t){e.error("Failed to load transition ("+i+"). Details: "+t.message)})}else{if(t.child!=t.activeView){if(t.cacheViews&&t.activeView){var r=n.getBindingInstruction(t.activeView);void 0==r.cacheViews||r.cacheViews?a(t.activeView).hide():o.removeNode(t.activeView)}t.child?(t.cacheViews||g(t.parent),a(t.child).show()):t.cacheViews||o.virtualElements.emptyNode(t.parent)}t.triggerAttach()}else t.cacheViews||o.virtualElements.emptyNode(t.parent),t.triggerAttach()},bindAndShow:function(e,t,r){t.child=e,t.composingNewView=t.cacheViews?-1==o.utils.arrayIndexOf(t.viewElements,e):!0,u(t,function(){if(t.binding&&t.binding(t.child,t.parent,t),t.preserveContext&&t.bindingContext)t.composingNewView&&(t.parts&&v(t),a(e).hide(),o.virtualElements.prepend(t.parent,e),n.bindContext(t.bindingContext,e,t.model));else if(e){var r=t.model||m,s=o.dataFor(e);if(s!=r){if(!t.composingNewView)return a(e).remove(),i.createView(e.getAttribute("data-view")).then(function(e){p.bindAndShow(e,t,!0)}),void 0;t.parts&&v(t),a(e).hide(),o.virtualElements.prepend(t.parent,e),n.bind(r,e)}}p.finalize(t)},r)},defaultStrategy:function(e){return t.locateViewForObject(e.model,e.area,e.viewElements)},getSettings:function(t){var n,a=t(),s=o.utils.unwrapObservable(a)||{},c=r.isActivator(a);if(e.isString(s))return s=i.isViewUrl(s)?{view:s}:{model:s,activate:!0};if(n=e.getModuleId(s))return s={model:s,activate:!0};!c&&s.model&&(c=r.isActivator(s.model));for(var u in s)s[u]=-1!=o.utils.arrayIndexOf(T,u)?o.utils.unwrapObservable(s[u]):s[u];return c?s.activate=!1:void 0===s.activate&&(s.activate=!0),s},executeStrategy:function(e){e.strategy(e).then(function(t){p.bindAndShow(t,e)})},inject:function(n){return n.model?n.view?(t.locateView(n.view,n.area,n.viewElements).then(function(e){p.bindAndShow(e,n)}),void 0):(n.strategy||(n.strategy=this.defaultStrategy),e.isString(n.strategy)?e.acquire(n.strategy).then(function(e){n.strategy=e,p.executeStrategy(n)}).fail(function(t){e.error("Failed to load view strategy ("+n.strategy+"). Details: "+t.message)}):this.executeStrategy(n),void 0):(this.bindAndShow(null,n),void 0)},compose:function(n,i,r,a){y++,a||(i=p.getSettings(function(){return i},n));var o=s(n);i.activeView=o.activeView,i.parent=n,i.triggerAttach=l,i.bindingContext=r,i.cacheViews&&!i.viewElements&&(i.viewElements=o.childElements),i.model?e.isString(i.model)?e.acquire(i.model).then(function(t){i.model=e.resolveObject(t),p.inject(i)}).fail(function(t){e.error("Failed to load composed module ("+i.model+"). Details: "+t.message)}):p.inject(i):i.view?(i.area=i.area||"partial",i.preserveContext=!0,t.locateView(i.view,i.area,i.viewElements).then(function(e){p.bindAndShow(e,i)})):this.bindAndShow(null,i)}},o.bindingHandlers.compose={init:function(){return{controlsDescendantBindings:!0}},update:function(e,t,n,r,a){var s=p.getSettings(t,e);if(s.mode){var c=o.utils.domData.get(e,k);if(!c){var u=o.virtualElements.childNodes(e);c={},"inline"===s.mode?c.view=i.ensureSingleElement(u):"templated"===s.mode&&(c.parts=f(u)),o.virtualElements.emptyNode(e),o.utils.domData.set(e,k,c)}"inline"===s.mode?s.view=c.view.cloneNode(!0):"templated"===s.mode&&(s.parts=c.parts),s.preserveContext=!0}p.compose(e,s,a,!0)}},o.virtualElements.allowedBindings.compose=!0,p});
define('durandal/events',["durandal/system"],function(t){var e=/\s+/,n=function(){},i=function(t,e){this.owner=t,this.events=e};return i.prototype.then=function(t,e){return this.callback=t||this.callback,this.context=e||this.context,this.callback?(this.owner.on(this.events,this.callback,this.context),this):this},i.prototype.on=i.prototype.then,i.prototype.off=function(){return this.owner.off(this.events,this.callback,this.context),this},n.prototype.on=function(t,n,r){var a,o,s;if(n){for(a=this.callbacks||(this.callbacks={}),t=t.split(e);o=t.shift();)s=a[o]||(a[o]=[]),s.push(n,r);return this}return new i(this,t)},n.prototype.off=function(n,i,r){var a,o,s,c;if(!(o=this.callbacks))return this;if(!(n||i||r))return delete this.callbacks,this;for(n=n?n.split(e):t.keys(o);a=n.shift();)if((s=o[a])&&(i||r))for(c=s.length-2;c>=0;c-=2)i&&s[c]!==i||r&&s[c+1]!==r||s.splice(c,2);else delete o[a];return this},n.prototype.trigger=function(t){var n,i,r,a,o,s,c,u;if(!(i=this.callbacks))return this;for(u=[],t=t.split(e),a=1,o=arguments.length;o>a;a++)u[a-1]=arguments[a];for(;n=t.shift();){if((c=i.all)&&(c=c.slice()),(r=i[n])&&(r=r.slice()),r)for(a=0,o=r.length;o>a;a+=2)r[a].apply(r[a+1]||this,u);if(c)for(s=[n].concat(u),a=0,o=c.length;o>a;a+=2)c[a].apply(c[a+1]||this,s)}return this},n.prototype.proxy=function(t){var e=this;return function(n){e.trigger(t,n)}},n.includeIn=function(t){t.on=n.prototype.on,t.off=n.prototype.off,t.trigger=n.prototype.trigger,t.proxy=n.prototype.proxy},n});
define('durandal/app',["durandal/system","durandal/viewEngine","durandal/composition","durandal/events","jquery"],function(t,e,n,i,r){function a(){return t.defer(function(e){return 0==s.length?(e.resolve(),void 0):(t.acquire(s).then(function(n){for(var i=0;i<n.length;i++){var r=n[i];if(r.install){var a=c[i];t.isObject(a)||(a={}),r.install(a),t.log("Plugin:Installed "+s[i])}else t.log("Plugin:Loaded "+s[i])}e.resolve()}).fail(function(e){t.error("Failed to load plugin(s). Details: "+e.message)}),void 0)}).promise()}var o,s=[],c=[];return o={title:"Application",configurePlugins:function(e,n){var i=t.keys(e);n=n||"plugins/",-1===n.indexOf("/",n.length-1)&&(n+="/");for(var r=0;r<i.length;r++){var a=i[r];s.push(n+a),c.push(e[a])}},start:function(){return t.log("Application:Starting"),this.title&&(document.title=this.title),t.defer(function(e){r(function(){a().then(function(){e.resolve(),t.log("Application:Started")})})}).promise()},setRoot:function(i,r,a){var o,s={activate:!0,transition:r};o=!a||t.isString(a)?document.getElementById(a||"applicationHost"):a,t.isString(i)?e.isViewUrl(i)?s.view=i:s.model=i:s.model=i,n.compose(o,s)}},i.includeIn(o),o});
define('plugins/history',["durandal/system","jquery"],function(t,e){function n(t,e,n){if(n){var i=t.href.replace(/(javascript:|#).*$/,"");t.replace(i+"#"+e)}else t.hash="#"+e}var i=/^[#\/]|\s+$/g,r=/^\/+|\/+$/g,a=/msie [\w.]+/,o=/\/$/,s={interval:50,active:!1};return"undefined"!=typeof window&&(s.location=window.location,s.history=window.history),s.getHash=function(t){var e=(t||s).location.href.match(/#(.*)$/);return e?e[1]:""},s.getFragment=function(t,e){if(null==t)if(s._hasPushState||!s._wantsHashChange||e){t=s.location.pathname;var n=s.root.replace(o,"");t.indexOf(n)||(t=t.substr(n.length))}else t=s.getHash();return t.replace(i,"")},s.activate=function(n){s.active&&t.error("History has already been activated."),s.active=!0,s.options=t.extend({},{root:"/"},s.options,n),s.root=s.options.root,s._wantsHashChange=s.options.hashChange!==!1,s._wantsPushState=!!s.options.pushState,s._hasPushState=!!(s.options.pushState&&s.history&&s.history.pushState);var o=s.getFragment(),c=document.documentMode,u=a.exec(navigator.userAgent.toLowerCase())&&(!c||7>=c);s.root=("/"+s.root+"/").replace(r,"/"),u&&s._wantsHashChange&&(s.iframe=e('<iframe src="javascript:0" tabindex="-1" />').hide().appendTo("body")[0].contentWindow,s.navigate(o,!1)),s._hasPushState?e(window).on("popstate",s.checkUrl):s._wantsHashChange&&"onhashchange"in window&&!u?e(window).on("hashchange",s.checkUrl):s._wantsHashChange&&(s._checkUrlInterval=setInterval(s.checkUrl,s.interval)),s.fragment=o;var l=s.location,d=l.pathname.replace(/[^\/]$/,"$&/")===s.root;if(s._wantsHashChange&&s._wantsPushState){if(!s._hasPushState&&!d)return s.fragment=s.getFragment(null,!0),s.location.replace(s.root+s.location.search+"#"+s.fragment),!0;s._hasPushState&&d&&l.hash&&(this.fragment=s.getHash().replace(i,""),this.history.replaceState({},document.title,s.root+s.fragment+l.search))}return s.options.silent?void 0:s.loadUrl()},s.deactivate=function(){e(window).off("popstate",s.checkUrl).off("hashchange",s.checkUrl),clearInterval(s._checkUrlInterval),s.active=!1},s.checkUrl=function(){var t=s.getFragment();return t===s.fragment&&s.iframe&&(t=s.getFragment(s.getHash(s.iframe))),t===s.fragment?!1:(s.iframe&&s.navigate(t,!1),s.loadUrl(),void 0)},s.loadUrl=function(t){var e=s.fragment=s.getFragment(t);return s.options.routeHandler?s.options.routeHandler(e):!1},s.navigate=function(e,i){if(!s.active)return!1;if(void 0===i?i={trigger:!0}:t.isBoolean(i)&&(i={trigger:i}),e=s.getFragment(e||""),s.fragment!==e){s.fragment=e;var r=s.root+e;if(s._hasPushState)s.history[i.replace?"replaceState":"pushState"]({},document.title,r);else{if(!s._wantsHashChange)return s.location.assign(r);n(s.location,e,i.replace),s.iframe&&e!==s.getFragment(s.getHash(s.iframe))&&(i.replace||s.iframe.document.open().close(),n(s.iframe.location,e,i.replace))}return i.trigger?s.loadUrl(e):void 0}},s.navigateBack=function(){s.history.back()},s});
define('plugins/router',["durandal/system","durandal/app","durandal/activator","durandal/events","durandal/composition","plugins/history","knockout","jquery"],function(t,e,n,i,r,a,o,s){function c(t){return t=t.replace(b,"\\$&").replace(p,"(?:$1)?").replace(m,function(t,e){return e?t:"([^/]+)"}).replace(h,"(.*?)"),new RegExp("^"+t+"$")}function u(t){var e=t.indexOf(":"),n=e>0?e-1:t.length;return t.substring(0,n)}function l(t){return t.router&&t.router.loadUrl}function d(t,e){return-1!==t.indexOf(e,t.length-e.length)}function f(t,e){if(!t||!e)return!1;if(t.length!=e.length)return!1;for(var n=0,i=t.length;i>n;n++)if(t[n]!=e[n])return!1;return!0}var v,g,p=/\((.*?)\)/g,m=/(\(\?)?:\w+/g,h=/\*\w+/g,b=/[\-{}\[\]+?.,\\\^$|#\s]/g,y=/\/$/,k=function(){function r(e,n){t.log("Navigation Complete",e,n);var i=t.getModuleId(D);i&&$.trigger("router:navigation:from:"+i),D=e,_=n;var r=t.getModuleId(D);r&&$.trigger("router:navigation:to:"+r),l(e)||$.updateDocumentTitle(e,n),g.explicitNavigation=!1,g.navigatingBack=!1,$.trigger("router:navigation:complete",e,n,$)}function s(e,n){t.log("Navigation Cancelled"),$.activeInstruction(_),_&&$.navigate(_.fragment,!1),M(!1),g.explicitNavigation=!1,g.navigatingBack=!1,$.trigger("router:navigation:cancelled",e,n,$)}function p(e){t.log("Navigation Redirecting"),M(!1),g.explicitNavigation=!1,g.navigatingBack=!1,$.navigate(e,{trigger:!0,replace:!0})}function m(t,e,n){g.navigatingBack=!g.explicitNavigation&&D!=n.fragment,$.trigger("router:route:activating",e,n,$),t.activateItem(e,n.params).then(function(i){if(i){var a=D;r(e,n),l(e)&&T({router:e.router,fragment:n.fragment,queryString:n.queryString}),a==e&&$.attached()}else t.settings.lifecycleData&&t.settings.lifecycleData.redirect?p(t.settings.lifecycleData.redirect):s(e,n);v&&(v.resolve(),v=null)})}function h(e,n,i){var r=$.guardRoute(n,i);r?r.then?r.then(function(r){r?t.isString(r)?p(r):m(e,n,i):s(n,i)}):t.isString(r)?p(r):m(e,n,i):s(n,i)}function b(t,e,n){$.guardRoute?h(t,e,n):m(t,e,n)}function w(t){return _&&_.config.moduleId==t.config.moduleId&&D&&(D.canReuseForRoute&&D.canReuseForRoute.apply(D,t.params)||D.router&&D.router.loadUrl)}function x(){if(!M()){var e=N.shift();if(N=[],e){if(e.router){var i=e.fragment;return e.queryString&&(i+="?"+e.queryString),e.router.loadUrl(i),void 0}M(!0),$.activeInstruction(e),w(e)?b(n.create(),D,e):t.acquire(e.config.moduleId).then(function(n){var i=t.resolveObject(n);b(L,i,e)}).fail(function(n){t.error("Failed to load routed module ("+e.config.moduleId+"). Details: "+n.message)})}}}function T(t){N.unshift(t),x()}function S(t,e,n){for(var i=t.exec(e).slice(1),r=0;r<i.length;r++){var a=i[r];i[r]=a?decodeURIComponent(a):null}var o=$.parseQueryString(n);return o&&i.push(o),{params:i,queryParams:o}}function A(e){$.trigger("router:route:before-config",e,$),t.isRegExp(e)?e.routePattern=e.route:(e.title=e.title||$.convertRouteToTitle(e.route),e.moduleId=e.moduleId||$.convertRouteToModuleId(e.route),e.hash=e.hash||$.convertRouteToHash(e.route),e.routePattern=c(e.route)),$.trigger("router:route:after-config",e,$),$.routes.push(e),$.route(e.routePattern,function(t,n){var i=S(e.routePattern,t,n);T({fragment:t,queryString:n,config:e,params:i.params,queryParams:i.queryParams})})}function I(e){if(t.isArray(e.route))for(var n=0,i=e.route.length;i>n;n++){var r=t.extend({},e);r.route=e.route[n],n>0&&delete r.nav,A(r)}else A(e);return $}function C(t){t.isActive||(t.isActive=o.computed(function(){var e=L();return e&&e.__moduleId__==t.moduleId}))}var D,_,N=[],M=o.observable(!1),L=n.create(),$={handlers:[],routes:[],navigationModel:o.observableArray([]),activeItem:L,isNavigating:o.computed(function(){var t=L(),e=M(),n=t&&t.router&&t.router!=$&&t.router.isNavigating()?!0:!1;return e||n}),activeInstruction:o.observable(null),__router__:!0};return i.includeIn($),L.settings.areSameItem=function(t,e,n,i){return t==e?f(n,i):!1},$.parseQueryString=function(t){var e,n;if(!t)return null;if(n=t.split("&"),0==n.length)return null;e={};for(var i=0;i<n.length;i++){var r=n[i];if(""!==r){var a=r.split("=");e[a[0]]=a[1]&&decodeURIComponent(a[1].replace(/\+/g," "))}}return e},$.route=function(t,e){$.handlers.push({routePattern:t,callback:e})},$.loadUrl=function(e){var n=$.handlers,i=null,r=e,o=e.indexOf("?");if(-1!=o&&(r=e.substring(0,o),i=e.substr(o+1)),$.relativeToParentRouter){var s=this.parent.activeInstruction();r=s.params.join("/"),r&&"/"==r[0]&&(r=r.substr(1)),r||(r=""),r=r.replace("//","/").replace("//","/")}r=r.replace(y,"");for(var c=0;c<n.length;c++){var u=n[c];if(u.routePattern.test(r))return u.callback(r,i),!0}return t.log("Route Not Found"),$.trigger("router:route:not-found",e,$),_&&a.navigate(_.fragment,{trigger:!1,replace:!0}),g.explicitNavigation=!1,g.navigatingBack=!1,!1},$.updateDocumentTitle=function(t,n){n.config.title?document.title=e.title?n.config.title+" | "+e.title:n.config.title:e.title&&(document.title=e.title)},$.navigate=function(t,e){return t&&-1!=t.indexOf("://")?(window.location.href=t,!0):(g.explicitNavigation=!0,a.navigate(t,e))},$.navigateBack=function(){a.navigateBack()},$.attached=function(){setTimeout(function(){M(!1),$.trigger("router:navigation:attached",D,_,$),x()},10)},$.compositionComplete=function(){$.trigger("router:navigation:composition-complete",D,_,$)},$.convertRouteToHash=function(t){if($.relativeToParentRouter){var e=$.parent.activeInstruction(),n=e.config.hash+"/"+t;return a._hasPushState&&(n="/"+n),n=n.replace("//","/").replace("//","/")}return a._hasPushState?t:"#"+t},$.convertRouteToModuleId=function(t){return u(t)},$.convertRouteToTitle=function(t){var e=u(t);return e.substring(0,1).toUpperCase()+e.substring(1)},$.map=function(e,n){if(t.isArray(e)){for(var i=0;i<e.length;i++)$.map(e[i]);return $}return t.isString(e)||t.isRegExp(e)?(n?t.isString(n)&&(n={moduleId:n}):n={},n.route=e):n=e,I(n)},$.buildNavigationModel=function(e){var n=[],i=$.routes;e=e||100;for(var r=0;r<i.length;r++){var a=i[r];a.nav&&(t.isNumber(a.nav)||(a.nav=e),C(a),n.push(a))}return n.sort(function(t,e){return t.nav-e.nav}),$.navigationModel(n),$},$.mapUnknownRoutes=function(e,n){var i="*catchall",r=c(i);return $.route(r,function(o,s){var c=S(r,o,s),u={fragment:o,queryString:s,config:{route:i,routePattern:r},params:c.params,queryParams:c.queryParams};if(e)if(t.isString(e))u.config.moduleId=e,n&&a.navigate(n,{trigger:!1,replace:!0});else if(t.isFunction(e)){var l=e(u);if(l&&l.then)return l.then(function(){$.trigger("router:route:before-config",u.config,$),$.trigger("router:route:after-config",u.config,$),T(u)}),void 0}else u.config=e,u.config.route=i,u.config.routePattern=r;else u.config.moduleId=o;$.trigger("router:route:before-config",u.config,$),$.trigger("router:route:after-config",u.config,$),T(u)}),$},$.reset=function(){return _=D=void 0,$.handlers=[],$.routes=[],$.off(),delete $.options,$},$.makeRelative=function(e){return t.isString(e)&&(e={moduleId:e,route:e}),e.moduleId&&!d(e.moduleId,"/")&&(e.moduleId+="/"),e.route&&!d(e.route,"/")&&(e.route+="/"),e.fromParent&&($.relativeToParentRouter=!0),$.on("router:route:before-config").then(function(t){e.moduleId&&(t.moduleId=e.moduleId+t.moduleId),e.route&&(t.route=""===t.route?e.route.substring(0,e.route.length-1):e.route+t.route)}),$},$.createChildRouter=function(){var t=k();return t.parent=$,t},$};return g=k(),g.explicitNavigation=!1,g.navigatingBack=!1,g.activate=function(e){return t.defer(function(n){if(v=n,g.options=t.extend({routeHandler:g.loadUrl},g.options,e),a.activate(g.options),a._hasPushState)for(var i=g.routes,r=i.length;r--;){var o=i[r];o.hash=o.hash.replace("#","")}s(document).delegate("a","click",function(t){if(g.explicitNavigation=!0,a._hasPushState&&!(t.altKey||t.ctrlKey||t.metaKey||t.shiftKey)){var e=s(this).attr("href"),n=this.protocol+"//";(!e||"#"!==e.charAt(0)&&e.slice(n.length)!==n)&&(t.preventDefault(),a.navigate(e))}})}).promise()},g.deactivate=function(){a.deactivate()},g.install=function(){o.bindingHandlers.router={init:function(){return{controlsDescendantBindings:!0}},update:function(t,e,n,i,a){var s=o.utils.unwrapObservable(e())||{};if(s.__router__)s={model:s.activeItem(),attached:s.attached,compositionComplete:s.compositionComplete,activate:!1};else{var c=o.utils.unwrapObservable(s.router||i.router)||g;s.model=c.activeItem(),s.attached=c.attached,s.compositionComplete=c.compositionComplete,s.activate=!1}r.compose(t,s,a)}},o.virtualElements.allowedBindings.router=!0},g});
define('util/routerExtension',["plugins/router"],function(t){var e={accountNavigationModel:ko.observableArray([]),adminNavigationModel:ko.observableArray([]),initMappedRoutes:function(){return $.each(this.routes,function(t,e){e.nav&&(e.isNavOnAuthenticate=e.nav),"isAdmin"in e&&e.isAdmin()&&(e.isAccountOnAuthenticate=e.isAdmin()&&!e.hideOnAuthenticate),"isAccount"in e&&e.isAccount()&&(e.isAccountOnAuthenticate=e.isAccount()&&!e.hideOnAuthenticate)}),this},secureMappedRoutes:function(t){return $.each(this.routes,function(e,n){if(n.nav=n.allowAnonymous||t&&n.isNavOnAuthenticate,"isAccount"in n){var i=t==n.isAccountOnAuthenticate;n.isAccount(i)}if("isAdmin"in n){var i=t==n.isAdminOnAuthenticate;n.isAdmin(i)}}),this.buildAccountNavigationModel(),this.buildAdminNavigationModel(),this},buildSecondaryNavigationModel:function(e,n){function i(e){e.isActive||(e.isActive=ko.computed(function(){var n=t.activeItem();return n&&n.__moduleId__==e.moduleId}))}for(var r=[],a=t.routes,o=0;o<a.length;o++){var s=a[o];e in s&&s[e]()&&(i(s),r.push(s))}return n(r),t},buildAccountNavigationModel:function(){this.buildSecondaryNavigationModel("isAccount",this.accountNavigationModel)},buildAdminNavigationModel:function(){this.buildSecondaryNavigationModel("isAdmin",this.adminNavigationModel)}},n={extendRouter:function(){$.extend(t,e)}};return n});
define('config',["plugins/router","util/routerExtension"],function(t,e){var i="breeze/ticketapi",n="breeze/ticketsecurityapi",o=[{route:"",moduleId:"home",title:$.i18n.t("appuitext:navMainHome"),nav:!0,allowAnonymous:!0,button:'<i class="icon-home"></i> '+$.i18n.t("appuitext:navMainHome")},{route:"tickets",moduleId:"ticketlist",title:$.i18n.t("appuitext:navMainTickets"),nav:!0,button:'<i class="icon-tasks"></i> '+$.i18n.t("appuitext:navMainTickets")},{route:"ticket/new",moduleId:"ticketcreate",title:$.i18n.t("appuitext:navMainTicketCreate"),nav:!0,button:'<i class="icon-plus-sign"></i> '+$.i18n.t("appuitext:navMainTicketCreate")},{route:"ticket/:id",moduleId:"ticketdetails",title:$.i18n.t("appuitext:navMainTicketDetails"),nav:!1},{route:"",moduleId:"home",title:"some admin page",nav:!1,isAdmin:ko.observable(!0)},{route:"logout",moduleId:"logout",title:$.i18n.t("appuitext:navAccountLogout"),nav:!1,isAccount:ko.observable(!0),hideOnAuthenticate:!1,button:'<i class="icon-signout"></i> '+$.i18n.t("appuitext:navAccountLogout")},{route:"login",moduleId:"login",title:$.i18n.t("appuitext:navAccountLogin"),nav:!1,isAccount:ko.observable(!0),hideOnAuthenticate:!0,button:'<i class="icon-signin"></i> '+$.i18n.t("appuitext:navAccountLogin")}],a=function(i,n){return e.extendRouter(),t.makeRelative({moduleId:"viewmodels"}).map(i).initMappedRoutes().secureMappedRoutes(n).buildNavigationModel().mapUnknownRoutes("login","login").activate()},u={remoteSecurityServiceName:n,remoteServiceName:i,router:t,activateForLogin:function(){return a(o,!1)},activate:function(){return a(o,!0)}};return u});
define('services/logger',["durandal/system"],function(t){function e(t,e,n,r){i(t,e,n,r,"info")}function n(t,e,n,r){i(t,e,n,r,"error")}function i(e,n,i,r,a){i=i?"["+i+"] ":"",n?t.log(i,e,n):t.log(i,e),r&&("error"===a?toastr.error(e):toastr.info(e))}var r={log:e,logError:n};return r});
requirejs.config({paths:{text:"../Scripts/text",durandal:"../Scripts/durandal",plugins:"../Scripts/durandal/plugins",transitions:"../Scripts/durandal/transitions"}}),define("jquery",[],function(){return jQuery}),define("knockout",[],function(){return ko}),define('main',["durandal/system","durandal/app","durandal/viewLocator","durandal/binder","services/logger"],function(t,e,n,i){t.debug(!0),e.configurePlugins({router:!0,dialog:!0}),e.start().then(function(){toastr.options.positionClass="toast-bottom-right",toastr.options.backgroundpositionClass="toast-bottom-right",n.useConvention();var t={useCookie:!1,ns:{namespaces:["appuitext","appmodeltext"],defaultNs:"appuitext"},resGetPath:"api/text/__lng__/__ns__"};window.location.search.indexOf("setLng=")||$.extend(t,{lng:window.ticketDeskUserLanguage()}),i.binding=function(t,e){$(e).i18n()},$.i18n.init(t,function(){e.title=$.i18n.t("appuitext:appName"),e.setRoot("viewmodels/shell","entrance")})})});
define('services/model',["config","durandal/system","services/logger"],function(t,e,n){function i(t){t.setEntityTypeForResourceName("TdUser","TdUser:#TicketDesk.Domain.Identity"),t.setEntityTypeForResourceName("SubmitterList","TdUser:#TicketDesk.Domain.Identity"),t.setEntityTypeForResourceName("StaffList","TdUser:#TicketDesk.Domain.Identity")}function r(t){return t.fetchMetadata(t.dataService).then(function(){a(t),t.metadataStore.setEntityTypeForResourceName("TagSuggestionList","TicketTag")})}function a(t){o(t,"Ticket","createdBy","required"),o(t,"Ticket","currentStatusSetBy","required"),o(t,"Ticket","lastUpdateBy","required")}function o(t,e,n,i){var r=t.metadataStore.getEntityType(e).getProperty(n).validators,a=$.grep(r,function(t){return t.name==i}),o=$.inArray(a[0],r);r.splice(o,1)}function s(t){c(t),t.registerEntityTypeCtor("Ticket",function(){this.isPartial=!1},l)}function c(t){var e={name:{dataType:breeze.DataType.String,isNullable:!1,isPartOfKey:!1},value:{dataType:breeze.DataType.String,isNullable:!1,isPartOfKey:!0}};t.addEntityType({shortName:"PrioritySetting",namespace:"TicketDesk.Domain.Model",dataProperties:e}),t.addEntityType({shortName:"CategorySetting",namespace:"TicketDesk.Domain.Model",dataProperties:e}),t.addEntityType({shortName:"TicketTypeSetting",namespace:"TicketDesk.Domain.Model",dataProperties:e}),t.addEntityType({shortName:"TicketStatusSetting",namespace:"TicketDesk.Domain.Model",dataProperties:e}),t.setEntityTypeForResourceName("PriorityList","PrioritySetting"),t.setEntityTypeForResourceName("TicketTypeList","CategorySetting"),t.setEntityTypeForResourceName("CategoryList","TicketTypeSetting"),t.setEntityTypeForResourceName("StatusList","TicketStatusSetting")}function l(t){t.tagListFormatted=ko.computed({read:function(){var e=t.tagList();return e?e.replace(/\,/g,", "):e},write:function(e){t.tagList(e.replace(/\, /g,","))}}),t.createdCombined=ko.computed({read:function(){return $.i18n.t("appmodeltext:ticketCreatedCombined",{date:moment(t.createdDate()).format("lll"),user:t.createdBy()})}}),t.lastUpdatedCombined=ko.computed({read:function(){return $.i18n.t("appmodeltext:ticketLastUpdatedCombined",{date:moment(t.lastUpdateDate()).format("lll"),user:t.lastUpdateBy()})}})}var u={ticket:"lastUpdateDate desc, assignedTo",tdUser:"userName"},d={ticket:"Ticket",priorityList:"PriorityList",categoryList:"CategoryList",ticketTypeList:"TicketTypeList",statusList:"StatusList",submitterList:"SubmitterList",staffList:"StaffList",tagSuggestionList:"TagSuggestionList"},f={configureSecurityMetadataStore:i,configureMetadataStore:s,entityNames:d,orderBy:u,loadMetadata:r};return f});
define('services/breeze.partial-entities',[],function(){function t(t,n,i,r,a){function o(n){var o=n[r],c=t.getEntityByKey(i,o);return c||(a=$.extend({},a||e),a[r]=o,c=t.createEntity(i,a)),s(c,n),c.entityAspect.setUnchanged(),c}function s(t,e){for(var n in e)e.hasOwnProperty(n)&&t[n](e[n]);return t}return n.map(o)}var e={isPartial:!0},n={mapDtosToEntities:t};return n});
define('services/datacontext',["durandal/system","services/model","config","services/logger","services/breeze.partial-entities"],function(t,e,n,i,r){function a(){g.hasChangesChanged.subscribe(function(t){k(t.hasChanges)})}function o(t,e,n){function i(n){e&&e(n.results),f("Retrieved ["+t+"] from remote data source",n,!0)}if(!n){var r=s(t,!0);if(r.length>0)return e(r),Q.resolve()}var a=p.from(t);return g.executeQuery(a).then(i).fail(u)}function s(t){var e=p.from(t);return g.executeQueryLocally(e)}function c(t){var e=t.message;return e.match(/validation error/i)?l(t):e}function l(t){try{var e=t.entityErrors.map(function(t){var e=t.errorMessage;return e}).join("; <br/>");return e}catch(n){}return"validation error"}function u(t){var e="Error retreiving data. "+t.message;throw v(e,t),t}function d(){breeze.NamingConvention.camelCase.setAsDefault();var t=new breeze.EntityManager(n.remoteServiceName);return t.metadataStore.hasMetadataFor(n.remoteServiceName)||e.configureMetadataStore(t.metadataStore),t}function f(e,n,r){i.log(e,n,t.getModuleId(V),r)}function v(e,n){i.logError(e,n,t.getModuleId(V),!0)}var p=breeze.EntityQuery,g=d(),m=e.orderBy,h=e.entityNames,b=ko.observable(0),y=ko.observable(0),k=ko.observable(!1),w=function(t,e){return o("TagSuggestionList",t,e)},x=function(t,e){return o("PriorityList",t,e)},T=function(t,e){return o("TicketTypeList",t,e)},S=function(t,e){return o("CategoryList",t,e)},A=function(t,e){return o("StatusList",t,e)},C=p.from("Tickets").where("ticketStatus","!=","Closed").orderBy(m.ticket),I=function(t,e,n){function i(){function n(e){e.results.length>0&&t(e.results)}var i=C.skip(5*e).take(5).using(breeze.FetchStrategy.FromLocalCache);return g.executeQuery(i).then(n).fail(u)}return n||b()<1?M().then(i):i()},M=function(){function t(t){b(t.inlineCount),r.mapDtosToEntities(g,t.results,h.ticket,"ticketId"),f("Retrieved [Tickets] from remote data source",t,!0)}var e=C.select("ticketId, title, ticketType, owner, assignedTo, ticketStatus, category, priority, createdBy, createdDate, lastUpdateBy, lastUpdateDate").using(breeze.FetchStrategy.FromServer).inlineCount(!0);return g.executeQuery(e).then(t).fail(u)},L=function(t){function e(e){function n(t){if(t.results.length>0){var e="Closed"!==t.results[0].ticketStatus();i!==e&&(e?b(b()+1):b(b()-1)),y(y()+1)}}f("refreshed Ticket "+t,e,!0);var i="Closed"!==e.entity.ticketStatus();return p.fromEntities(e.entity).using(g).execute().then(n)}return g.fetchEntityByKey(h.ticket,t,!0).then(e).fail(u)},$=function(){return g.createEntity(h.ticket)},D=function(t,e){function n(t){var n=t.entity;return n.isPartial()?i(n):e(n)}function i(t){return p.fromEntities(t).using(g).execute().then(r).fail(u)}function r(t){var n=t.results[0];return n.isPartial(!1),f("Retrieved [Ticket] from remote data source",n,!0),e(n)}return g.fetchEntityByKey(h.ticket,t,!0).then(n).fail(u)},N=function(){g.rejectChanges(),f("Canceled changes",null,!0)},_=function(){function t(t){f("Saved data successfully",t,!0)}function e(t){var e="Save failed: "+c(t);throw v(e,t),t.message=e,t}return g.saveChanges().then(t).fail(e)},E=function(){b(0),y(0),g=null},O=!1,P=function(){return f("Priming Data",null,!0),g=d(),e.loadMetadata(g).then(function(){O=!0}).then(a)},V={getPriorityList:x,getTicketTypeList:T,getCategoryList:S,getStatusList:A,getTagSuggestionList:w,hasChanges:k,cancelChanges:N,saveChanges:_,getOpenTicketPagedList:I,openTicketRowCount:b,refreshTicketById:L,backgroudTicketRefreshCounter:y,createTicket:$,getTicketById:D,primeData:P,reset:E};return V});
define('services/notifiercontext',["durandal/system","services/model","config","services/logger","services/datacontext"],function(t,e,n,i,r){var a=function(){$.connection.hub.stop(),i.log("SignalR no longer listening for ticket updates",null,t.getModuleId(r),!0)},o=function(){var e=$.connection.ticketDeskHub;$.connection.hub.start(),i.log("SignalR listening for ticket updates",null,t.getModuleId(r),!0),e.client.ticketChanged=function(t){i.log("Server says: ticket "+t+" changed",null,"home",!0),r.refreshTicketById(t)}},s=function(){};return{activate:s,stopHubs:a,startHubs:o}});
define('services/securitycontext',["durandal/system","services/model","config","services/logger"],function(t,e,n,i){function r(e,n,r){i.log(e,n,t.getModuleId(m),r)}function a(t){var e=l.from(t).orderBy(d.tdUser);return u.executeQueryLocally(e)}function o(t,e){function n(n){t&&t(n.results),r("Retrieved ["+e+"] from remote data source",n,!0)}var i=l.from(e).orderBy(d.tdUser);return u.executeQuery(i).then(n).fail(s)}function s(t){var e="Error retreiving data. "+t.message;throw logError(e,t),t}function c(){breeze.NamingConvention.camelCase.setAsDefault();var t=new breeze.EntityManager(n.remoteSecurityServiceName);return t.metadataStore.hasMetadataFor(n.remoteSecurityServiceName)||e.configureSecurityMetadataStore(t.metadataStore),t}var l=breeze.EntityQuery,u=c(),d=e.orderBy,f=e.entityNames,v=function(){return r("Priming Security Data",null,!0),u=c(),u.fetchMetadata(u.dataService)},p=function(t,e){if(!e){var n=a(f.staffList,!0);if(n.length>0)return t(n),Q.resolve()}return o(t,f.staffList)},g=function(t,e){if(!e){var n=a(f.submitterList,!0);if(n.length>0)return t(n),Q.resolve()}return o(t,f.submitterList)},m={primeData:v,getTdSubmitters:g,getTdStaff:p};return m});
define('services/account',["durandal/system","services/datacontext","config","plugins/router","services/logger","services/notifiercontext","services/securitycontext"],function(t,e,n,i,r,a,o){var s=function(){return Q.when($.ajax({url:"/api/useraccount/logout",type:"GET",contentType:"application/json",data:JSON.stringify({action:"logout"})})).then(function(){u(!1)}).then(e.reset).then(a.stopHubs).fail(d)},c=function(){return Q.when($.ajax({url:"/api/useraccount/authenticationcheck",type:"GET",contentType:"application/json"}))},l=function(t,n,r){var s={username:t,password:n,rememberme:r};return Q.when($.ajax({url:"/api/useraccount/login",type:"POST",contentType:"application/json",dataType:"json",data:JSON.stringify(s)})).then(function(){u(!0)}).then(e.primeData).then(o.primeData).then(a.startHubs).then(function(){i.navigate("")}).fail(d)},u=function(t){return i.secureMappedRoutes(t).buildNavigationModel(),!0},d=function(e,n){if(msg=n,e.responseJSON){var i=e.responseJSON.result;msg="server says: "+i}throw r.logError(msg,e,t.getModuleId(v),!0),e},v={checkAuthentication:c,logoutUser:s,loginUser:l};return v});
define('viewmodels/home',["services/logger"],function(t){function e(){return t.log("Home View Activated",null,"home"),!0}var n={activate:e,title:$.i18n.t("appuitext:viewHomeTitle")};return n});
define('viewmodels/login',["durandal/system","services/account","plugins/router","services/logger"],function(t,e,n,i){var r=function(t,e){return 13==e.keyCode&&($("#loginbutton").focus(),a()),!0},a=function(){var n=$("#loginTarget").contents().find("#loginForm"),r=$("#username").val(),a=$("#password").val(),o=$("#rememberme").val();n.find("#username").val(r),n.find("#password").val(a),n.submit(),e.loginUser(r,a,o).fail(function(){i.logError($.i18n.t("appuitext:viewLoginFailedErrorMessage"),null,t.getModuleId(c),!0)})};window.formLoaded=function(){};var o=function(){$("#loginTarget").ready(window.setTimeout(function(){var t=$("#loginTarget").contents().find("#loginForm");$("#username").val(t.find("#username").val()),$("#password").val(t.find("#password").val())},100))},s=function(){$("#username").val(""),$("#password").val("")},c={deactivate:s,attached:o,keyMonitor:r,doLogin:a,title:$.i18n.t("appuitext:viewLoginTitle")};return c});
define('viewmodels/logout',["services/account","services/logger","plugins/router","config"],function(t,e,n){var i=function(){return e.log("Logging out",null,"login",!1),t.logoutUser().then(r)},r=function(){window.setTimeout(function(){n.navigate("")},1e3)};return{compositionComplete:i,title:$.i18n.t("appuitext:viewLogoutTitle")}});
define('viewmodels/nav',["durandal/system","plugins/router","services/logger","durandal/composition"],function(t,e,n){var i=ko.computed(function(){return e.adminNavigationModel().length>0}),r=function(){$("#navMainButton").is(":visible")&&$("#navMain").collapse("hide")},a={attached:function(){e.on("router:navigation:composition-complete",r)},router:e,hasAdminRoutes:i};return a});
define('viewmodels/shell',["durandal/system","plugins/router","config","services/account","services/datacontext","services/logger","services/notifiercontext","services/securitycontext"],function(t,e,n,i,r,a,o,s){function c(){navigator.appVersion.indexOf("MSIE")&&(elems=[$("body"),$("#applicationHost"),$(".durandal-wrapper"),$("html")],elems.forEach(function(t){t.css("height","100%").css("position","relative")}))}function u(){var t=this;return Q.when(i.checkAuthentication().then(function(){t.isAuthenticated=!0}).fail(function(){t.isAuthenticated=!1})).then(function(){return t.isAuthenticated?r.primeData().then(s.primeData).then(o.startHubs).then(n.activate):(window.location.href.indexOf("#login")<0&&window.location.replace("/#login"),n.activateForLogin())}).then(function(){l("TicketDesk SPA Loaded!",null,!0)})}function l(e,n,i){a.log(e,n,t.getModuleId(f),i)}var d=!1,f={router:e,activate:u,attached:c,isAuthenticated:d};return f});
define('viewmodels/ticketcreate',["durandal/app","services/datacontext","plugins/router","services/logger","services/securitycontext"],function(t,e,n,i,r){var a=ko.observableArray(),o=ko.observableArray(),s=ko.observableArray(),c=ko.observable(!1),u=ko.observable(!1),l=ko.observable(),d=ko.observableArray(),f=ko.observableArray(),v=ko.observableArray(),g=function(){return Q.all([e.getPriorityList(d),e.getTicketTypeList(v),e.getCategoryList(f),e.getTagSuggestionList(o),r.getTdSubmitters(a),r.getTdStaff(s)]).then(function(){l(e.createTicket()),i.log("Ticket Create View Activated",null,"TicketCreate",!1)})},p=function(){n.navigateBack()},m=ko.computed(function(){return e.hasChanges()}),h=function(){b(!1)},b=function(t){e.cancelChanges(),t||l(e.createTicket())},y=ko.computed(function(){return m()&&!c()}),k=function(){if(u())return!1;if(m()){var e=$.i18n.t("appuitext:navNavigateAwayConfirmDialogTitle",{pagetitle:T.title}),n=$.i18n.t("appuitext:navNavigateAwayConfirmDialogMessage"),i=function(t){var e=t===$.i18n.t("appuitext:generalYes");return e&&b(!0),e};return t.showMessage(e,n,[$.i18n.t("appuitext:generalYes"),$.i18n.t("appuitext:generalNo")]).then(i)}return!0},w=function(){function t(){c(!1),n.navigate("#/ticket/"+l().ticketId(),{replace:!0})}return l().ticketStatus("Active"),c(!0),e.saveChanges().then(t)},x=function(){$("#tagList").tagit({availableTags:$.map(o(),function(t){return t.tagName()})}),function(){var t=Markdown.getSanitizingConverter();t.hooks.chain("preBlockGamut",function(t,e){return t.replace(/^ {0,3}""" *\n((?:.*?\n)+?) {0,3}""" *$/gm,function(t,n){return"<blockquote>"+e(n)+"</blockquote>\n"})}),t.hooks.chain("preConversion",function(t){return t.replace(/(\w+)\n/g,"$1  \n")}),t.hooks.chain("plainLinkText",function(t){return t});var e=new Markdown.Editor(t,"-ticketDetails",null);e.run(),i.log("Ticket Create View Editor Initialized",null,"TicketCreate",!1)}()},T={attached:x,activate:g,title:$.i18n.t("appuitext:viewTicketCreateTitle"),cancel:h,canDeactivate:k,canSave:y,goBack:p,hasChanges:m,save:w,ticket:l,categoryList:f,ticketTypeList:v,priorityList:d,submitterList:a,staffList:s,tagList:o};return T});
define('viewmodels/ticketdetails',["durandal/app","services/datacontext","plugins/router","services/logger"],function(t,e,n){var i=ko.observable(),r=ko.observableArray(),a=ko.observableArray(),o=ko.observableArray(),s=ko.observableArray(),c=ko.observable(!1),u=ko.observable(!1),l=function(t){var t=parseInt(t);return Q.all([e.getTicketById(t,i),e.getPriorityList(r),e.getTicketTypeList(s),e.getCategoryList(a),e.getStatusList(o)])},d=function(){n.navigateBack()},f=ko.computed(function(){return e.hasChanges()}),v=function(){e.cancelChanges()},g=ko.computed(function(){return f()&&!c()}),p=function(){function t(){c(!1)}return c(!0),e.saveChanges().fin(t)},m=function(){if(u())return!1;if(f()){var e=$.i18n.t("appuitext:navNavigateAwayConfirmDialogTitle",{pagetitle:i().title()}),n=$.i18n.t("appuitext:navNavigateAwayConfirmDialogMessage"),r=function(t){return t===$.i18n.t("appuitext:generalYes")&&v(),t};return t.showMessage(e,n,[$.i18n.t("appuitext:generalYes"),$.i18n.t("appuitext:generalNo")]).then(r)}return!0},h={activate:l,title:$.i18n.t("appuitext:viewTicketDetailsTitle"),cancel:v,canDeactivate:m,canSave:g,goBack:d,hasChanges:f,save:p,ticket:i,categoryList:a,ticketTypeList:s,priorityList:r,statusList:o};return h});
define('viewmodels/ticketlist',["services/datacontext","plugins/router","services/logger"],function(t,e,n){var i=ko.observableArray(),r=ko.observable(),a=function(){return r()-1},o=!1,s=function(){o^=1},c=!1,u=function(){c^=1},l=function(){return ko.bindingHandlers.ticketChanged={update:function(t,e,i,r,a){var o=e();if(ko.utils.unwrapObservable(o),"true"===$(t).attr("data-listenforchanges")){n.log("ticketChanged",null,null,!1);var s=$(t).fadeTo(50,.3).fadeTo(450,1);"Closed"!=a.$data.ticketStatus()||s.css({"background-color":"rgba(200,200,200,0.8)"})}}},t.backgroudTicketRefreshCounter.subscribe(v),r(1),n.log("Ticket List View Activated",null,"TicketList",!1),t.getOpenTicketPagedList(i,a()).finally(u)},d=function(t){1!==t.nodeType||o||$(t).hide().fadeIn(500)},f=function(t){1===t.nodeType&&(o?$(t).remove():$(t).fadeOut(500,function(){$(t).remove()}))},v=function(){c&&(n.log("ticketCountChanged",null,null,!1),b()<r()?w():(u(),t.getOpenTicketPagedList(i,a()).then(u)))},g=function(t){t.forEach(function(t){"ARTICLE"===t.nodeName&&$(t).attr("data-listenforchanges","true")})},p={marginRight:0,marginLeft:0,opacity:1},m={marginLeft:"40px",marginRight:"- 40px",opacity:0,display:"block"},h={marginLeft:"-40px",marginRight:"40px",opacity:0,display:"block"},b=ko.computed(function(){return Math.ceil(t.openTicketRowCount()/5)}),y=ko.computed(function(){return r()>1}),k=ko.computed(function(){return r()<b()}),w=function(){function e(){n.css(h),n.animate(p,300,"swing"),u(),s()}var n=$(".view-list");return y()?(u(),s(),r(r()-1),n.css(p),Q.all([$.when(n.animate(m,300,"swing")),t.getOpenTicketPagedList(i,a())]).then(e)):Q.resolve()},x=function(){function e(){n.css(m),n.animate(p,200,"swing"),u(),s()}var n=$(".view-list");return k()?(u(),s(),r(r()+1),n.css(p),Q.all([$.when(n.animate(h,200,"swing")),t.getOpenTicketPagedList(i,a())]).then(e)):Q.resolve()},T=function(){i([])},S=function(){return u(),t.getOpenTicketPagedList(i,a(),!0).then(u)},A=function(t){if(t&&t.ticketId()){var n="#/ticket/"+t.ticketId();e.navigate(n)}},C=function(t){L(t,".ticket-brief",A)},L=function(t,e,n,i){var r=i||"click";$(t).on(r,e,function(){var t=ko.dataFor(this);return n(t),!1})},I={showTicketElement:d,hideTicketElement:f,previous:w,next:x,maxPage:b,currentPage:r,canPrev:y,canNext:k,rowCount:t.openTicketRowCount,activate:l,deactivate:T,refresh:S,tickets:i,title:$.i18n.t("appuitext:viewTicketListTitle"),attached:C,ticketItemsRendered:g};return I});
define('text',{load: function(id){throw new Error("Dynamic load not allowed: " + id);}});
define('text!views/footer.html',[],function () { return '<small class="pull-right">\n    <a href="https://github.com/StephenRedd/TicketDesk" data-i18n="appuitext:appName" />- <span data-i18n="viewFooterCopyright"></span>\n</small>';});

define('text!views/home.html',[],function () { return '<header class="page-header">\n    <h1 data-bind="text: title"></h1>\n</header>\n<section id="content" class="container" style="height: 100%; min-height: 300px;">\n    <p data-i18n="[html]appuitext:viewHomeContent"></p>\n</section>\n';});

define('text!views/login.html',[],function () { return '<header class="page-header">\r\n    <h1 data-bind="text: title"></h1>\r\n</header>\r\n<section id="content" class="container col-md-12">\r\n    <iframe class="col-md-12" id="loginTarget" src="/account/loginform" seamless="seamless" style="overflow:hidden;height:0px;" frameborder="0"> </iframe>\r\n    <form action="api/useraccount/logindummy">\r\n        <div class="panel panel-default" data-bind="event: { keypress: keyMonitor }">\r\n            <div class=" btn-toolbar panel-heading">\r\n                <div class="btn-group btn-group-sm">\r\n                    <button id="loginbutton" class="btn btn-primary btn-sm" data-bind="click: doLogin" data-i18n="appuitext:viewLoginLoginButtonLabel"></button>\r\n                </div>\r\n            </div>\r\n            <div class="panel-body">\r\n                <div class="form-horizontal">\r\n                    <div class="form-group">\r\n                        <label class="col-md-2 col-sm-2 control-label" for="username" data-i18n="appuitext:viewLoginUserNameFieldLabel">: </label>\r\n                        <div class="col-md-3 col-sm-3">\r\n                            <input class="form-control input-sm" id="username" name="username" type="text" />\r\n                        </div>\r\n                    </div>\r\n                    <div class="form-group">\r\n                        <label class="col-md-2 col-sm-2  control-label" for="password" data-i18n="appuitext:viewLoginPasswordFieldLabel">: </label>\r\n                        <div class="col-md-3 col-sm-3">\r\n                            <input class="form-control input-sm" id="password" name="password" type="password" />\r\n                        </div>\r\n                    </div>\r\n\r\n                    <div class="form-group">\r\n                        <div class="col-md-3 col-sm-3 col-md-offset-2 col-sm-offset-2">\r\n                            <label class="checkbox" for="rememberme">\r\n                                <input class="" type="checkbox" id="rememberme" checked="checked" />\r\n                                <!--ko text: $.i18n.t(\'appuitext:viewLoginRememberMeFieldLabel\') -->\r\n                                <!--/ko-->\r\n\r\n                            </label>\r\n                        </div>\r\n\r\n                    </div>\r\n\r\n                </div>\r\n            </div>\r\n        </div>\r\n    </form>\r\n</section>\r\n';});

define('text!views/logout.html',[],function () { return '<header class="page-header">\n    <h1 data-bind="text: title"></h1>\n</header>\n\n<section>\n    <div class="progress progress-striped active" style="width: 80%; margin-left: auto; margin-right: auto;">\n        <div class="progress-bar" role="progressbar" aria-valuenow="100" aria-valuemin="0" aria-valuemax="100" style="width: 100%">\n        </div>\n    </div>\n\n    \n</section>';});

define('text!views/nav.html',[],function () { return '<div class="navbar navbar-default navbar-fixed-top" role="navigation">\r\n    <div class="container">\r\n        <!-- Brand and toggle get grouped for better mobile display -->\r\n        <div class="navbar-header">\r\n            <button id="navMainButton" type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-ex1-collapse">\r\n                <span class="sr-only" data-i18n="appuitext:navMainToggleNavigation"></span>\r\n                <span class="icon-bar"></span>\r\n                <span class="icon-bar"></span>\r\n                <span class="icon-bar"></span>\r\n            </button>\r\n            <a href="/#" data-i18n="[class]appuitext:cssNavLogo"></a>\r\n        </div>\r\n        <!-- Collect the nav links, forms, and other content for toggling -->\r\n        <div id="navMain" class="navbar-collapse collapse navbar-ex1-collapse">\r\n            <ul class="nav navbar-nav" data-bind="foreach: router.navigationModel">\r\n                <li data-bind="css: { active: isActive }">\r\n                    <a data-bind="attr: { href: hash }, text: title, html: button"></a>\r\n                </li>\r\n            </ul>\r\n            <ul class="nav navbar-nav navbar-right">\r\n                <li class="dropdown" data-bind="visible: hasAdminRoutes()">\r\n                    <a href="#" class="dropdown-toggle" data-toggle="dropdown"><i class="icon-cog"></i> <span data-i18n="appuitext:navMainAdmin"></span><b class="caret"></b></a>\r\n                    <ul class="dropdown-menu" data-bind="foreach: router.adminNavigationModel">\r\n                        <li data-bind="css: { active: $parent.router.isActive }">\r\n                            <a data-bind="attr: { href: hash }, text: title"></a>\r\n                        </li>\r\n\r\n                    </ul>\r\n                </li>\r\n                <!-- ko foreach: router.accountNavigationModel -->\r\n                <li data-bind="css: { active: $data.isActive }">\r\n                    <a data-bind="attr: { href: $data.hash }, text: $data.title, html: $data.button"></a>\r\n                </li>\r\n                <!-- /ko -->\r\n                <li>\r\n                    <a id="loader" data-bind="css: { active: router.isNavigating }">\r\n                        <i class="nav-loader icon-spinner icon-2x icon-spin" style="margin-right: 15px;"></i>\r\n                    </a>\r\n                </li>\r\n\r\n            </ul>\r\n        </div>\r\n\r\n\r\n\r\n        <!-- /.navbar-collapse -->\r\n\r\n\r\n        <!--   <div class="nav navbar-text progress" style="width: 300px; margin-top:10px">\r\n                <div class="bar" style="width: 30%;"></div>\r\n            </div> -->\r\n        <!--<div class="loader pull-right" data-bind="css: { active: router.isNavigating }">\r\n            <div class="progress progress-striped active page-progress-bar">\r\n                <div class="bar" style="width: 100px;"></div>\r\n            </div>\r\n        </div>-->\r\n    </div>\r\n</div>\r\n\r\n<!---->\r\n';});

define('text!views/shell.html',[],function () { return '\n\n<div id="wrap">\n    <header data-bind="compose: \'viewmodels/nav\'"></header>\n    \n    <section id="content" class="bodyContent container" data-bind="router: { transition: \'entrance\', cacheViews: false, duration: 200 }"></section>\n\n</div>\n<footer id="footer">\n    <div class="container" data-bind="compose: { view: \'footer\' }"></div>\n</footer>\n\n';});

define('text!views/ticketcreate.html',[],function () { return '<section id="session-view">\r\n\r\n    <header class="page-header">\r\n        <h1 data-bind="text: title"></h1>\r\n    </header>\r\n    <div class="panel panel-default">\r\n        <div class="btn-toolbar panel-heading">\r\n            <div class="btn-group btn-group-sm">\r\n                <button class="btn btn-primary btn-sm"\r\n                        data-bind="click: goBack">\r\n                    <i class="icon-hand-left"></i>&nbsp;<span data-i18n="appuitext:generalBack" />\r\n                </button>\r\n                <button class="btn btn-primary btn-sm"\r\n                        data-bind="click: cancel, enable: canSave">\r\n                    <i class="icon-undo"></i>&nbsp;<span data-i18n="appuitext:generalCancel" />\r\n                </button>\r\n            </div>\r\n            <div class="btn-group">\r\n                <button class="btn btn-success btn-sm"\r\n                        data-bind="click: save, enable: canSave">\r\n                    <i class="icon-save"></i>&nbsp;<span data-i18n="appuitext:generalSave" />\r\n                </button>\r\n\r\n            </div>\r\n            <div class="btn-group">\r\n                <i class="icon-asterisk" data-bind="visible: hasChanges" style="color: orange;"></i>\r\n            </div>\r\n        </div>\r\n        <section class="panel-body" data-bind="with: ticket">\r\n            <div class="form-horizontal">\r\n\r\n                <div class="form-group">\r\n                    <label class="col-md-1 col-sm-1 control-label" for="title" data-i18n="appmodeltext:ticketTitle"></label>\r\n                    <div class="col-md-8 col-sm-11">\r\n                        <input type="text" class="form-control input-sm" id="title" data-bind="value: title" data-i18n="[placeholder]appmodeltext:ticketTitlePrompt" />\r\n                    </div>\r\n                </div>\r\n\r\n                <div class="form-group">\r\n                    <label class="col-md-1 col-sm-1 control-label" for="ticketType" data-i18n="appmodeltext:ticketTicketType"></label>\r\n                    <div class="col-md-3 col-sm-3">\r\n                        <select id="ticketType" class="form-control input-sm"\r\n                                data-bind="options: $parent.ticketTypeList,\r\n                                    optionsText: function(item){\r\n                                        var key = \'appmodeltext:ticketType\' + item.value();\r\n                                        return $.i18n.t(key);},\r\n                                    optionsValue: \'value\',\r\n                                    value: ticketType,\r\n                                    optionsCaption: \' \'"></select>\r\n                    </div>\r\n\r\n\r\n                    <label class="col-md-1 col-sm-2 control-label" for="category" data-i18n="appmodeltext:ticketCategory"></label>\r\n                    <div class="col-md-3 col-sm-3">\r\n                        <select id="category" class="form-control input-sm"\r\n                                data-bind="options: $parent.categoryList,\r\n                                    optionsText:  function(item){\r\n                                        var key = \'appmodeltext:category\' + item.value();\r\n                                        return $.i18n.t(key);},\r\n                                    optionsValue: \'value\',\r\n                                    value: category,\r\n                                    optionsCaption: \' \'"></select>\r\n                    </div>\r\n\r\n                    <label class="col-md-1 col-sm-1 control-label" for="priority" data-i18n="appmodeltext:ticketPriority"></label>\r\n                    <div class="col-md-3 col-sm-2">\r\n                        <select id="priority" class="form-control input-sm"\r\n                                data-bind="options: $parent.priorityList,\r\n                                    optionsText: function(item){\r\n                                        var key = \'appmodeltext:priority\' + item.value();\r\n                                        return $.i18n.t(key);},\r\n                                    optionsValue: \'value\',\r\n                                    value: priority,\r\n                                    optionsCaption: \' \'"></select>\r\n                    </div>\r\n                </div>\r\n\r\n                <div class="form-group">\r\n                    <label class="col-md-1 col-sm-1 control-label" for="tagList" data-i18n="appmodeltext:ticketTagList"></label>\r\n                    <div class="col-md-7 col-sm-7">\r\n                        \r\n\r\n                        <input type="text" class="form-control input-sm" id="tagList"\r\n                               \r\n                               data-bind="value: tagListFormatted"\r\n                               data-i18n="[placeholder]appmodeltext:ticketTagPrompt" />\r\n                    </div>\r\n                    <div class="col-md-4 col-sm-4">\r\n                        <label class="checkbox" for="affectsCustomer">\r\n                            <input class="" type="checkbox" id="affectsCustomer" data-bind="checked: affectsCustomer" />\r\n                            <!-- ko text: $.i18n.t(\'appmodeltext:ticketAffectsCustomer\')--><!--/ko-->\r\n                        </label>\r\n                    </div>\r\n                </div>\r\n                <div class="form-group">\r\n                    <label class="col-md-1 col-sm-1 control-label" for="wmd-input-ticketDetails" data-i18n="appmodeltext:ticketDetails"></label>\r\n                    <div class="col-md-11 col-sm-11 wmd-panel">\r\n                        <div class="tabbable">\r\n\r\n                            <div class="tab-content">\r\n                                <ul class="nav nav-tabs pull-right">\r\n                                    <li class="active"><a href="#tab1" data-toggle="tab"><i class="icon-edit"></i></a></li>\r\n                                    <li><a href="#tab2" data-toggle="tab"><i class="icon-search"></i></a></li>\r\n                                </ul>\r\n                                <div class="tab-pane" id="tab2">\r\n                                    <div class="row" style="min-height: 35px;"></div>\r\n                                    <div id="wmd-preview-ticketDetails" class="wmd-panel wmd-preview form-control"></div>\r\n                                </div>\r\n                                <div class="tab-pane active" id="tab1">\r\n                                    <div id="wmd-button-bar-ticketDetails" style="display: inline-block"></div>\r\n                                    <div>\r\n\r\n                                        <textarea class="wmd-input form-control" id="wmd-input-ticketDetails" name="ticketDetails" rows="10" data-bind="value: details" style="height: 250px;"></textarea>\r\n                                    </div>\r\n\r\n                                </div>\r\n                            </div>\r\n\r\n                        </div>\r\n                    </div>\r\n\r\n                </div>\r\n                <div class="form-group">\r\n                    <label class="col-md-2 col-sm-2 control-label" for="owner" data-i18n="appmodeltext:ticketOwner"></label>\r\n                    <div class="col-md-4 col-sm-4">\r\n                        <select id="owner" class="form-control input-sm"\r\n                                data-bind="options: $parent.submitterList,\r\n                                    optionsText: \'userName\',\r\n                                    optionsValue:\'userName\',\r\n                                    value: owner,\r\n                                    optionsCaption: \' \'"></select>\r\n                    </div>\r\n\r\n\r\n\r\n                    <label class="col-md-2 col-sm-2 control-label" for="assignedTo" data-i18n="appmodeltext:ticketAssignedTo"></label>\r\n                    <div class="col-md-4 col-sm-4">\r\n                        <select id="owner" class="form-control input-sm"\r\n                                data-bind="options: $parent.staffList,\r\n                                    optionsText: \'userName\',\r\n                                    optionsValue:\'userName\',\r\n                                    value: assignedTo,\r\n                                    optionsCaption: \' \'"></select>\r\n\r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </section>\r\n    </div>\r\n</section>';});

define('text!views/ticketdetails.html',[],function () { return '<section id="session-view" class="view">\r\n    <h2 class="page-title" data-bind="text: title"></h2>\r\n    <div class="button-bar btn-block">\r\n        <button class="btn btn-info"\r\n            data-bind="click: goBack">\r\n            <i class="icon-hand-left"></i> Back</button>\r\n        <button class="btn btn-info"\r\n            data-bind="click: cancel, enable: canSave">\r\n            <i class="icon-undo"></i> Cancel</button>\r\n        <button class="btn btn-info"\r\n            data-bind="click: save, enable: canSave">\r\n            <i class="icon-save"></i> Save</button>\r\n        <!--        <button class="btn btn-danger"\r\n            data-bind="click: deleteSession, disable: hasChanges">\r\n            <i class="icon-trash"></i>Delete\r\n        </button>-->\r\n        <i class="icon-asterisk" data-bind="visible: hasChanges"></i>\r\n    </div>\r\n    <div class="form-horizontal" data-bind="with: ticket">\r\n        <div>\r\n            <div class="control-group">\r\n                <label class="control-label" for="title">Title</label>\r\n                <div class="controls">\r\n                    <input type="text" id="title" data-bind="value: title"\r\n                        placeholder="Ticket title" />\r\n                </div>\r\n            </div>\r\n\r\n            <div class="control-group">\r\n                <label class="control-label" for="category">Status</label>\r\n                <div class="controls">\r\n                    <select id="ticketStatus" data-bind="options: $parent.statusList, optionsText: \'name\',\r\n                        optionsValue: \'value\', value: ticketStatus, optionsCaption: \'--select--\'">\r\n                    </select>\r\n                </div>\r\n\r\n            </div>\r\n\r\n            <div class="control-group">\r\n                <label class="control-label" for="category">Category</label>\r\n                <div class="controls">\r\n                    <select id="category" data-bind="options: $parent.categoryList, optionsText: \'value\',\r\n                        optionsValue: \'value\', value: category, optionsCaption: \'--select--\'">\r\n                    </select>\r\n                </div>\r\n\r\n            </div>\r\n            <div class="control-group">\r\n                <label class="control-label" for="ticketType">Type</label>\r\n                <div class="controls">\r\n                    <select id="ticketType" data-bind="options: $parent.ticketTypeList, optionsText: \'value\',\r\n                        optionsValue: \'value\', value: ticketType, optionsCaption: \'--select--\'">\r\n                    </select>\r\n                </div>\r\n\r\n            </div>\r\n            <div class="control-group">\r\n                <label class="control-label" for="priority">Priority</label>\r\n                <div class="controls">\r\n                    <select id="priority" data-bind="options: $parent.priorityList, optionsText: \'value\',\r\n                        optionsValue: \'value\', value: priority, optionsCaption: \'--select--\'">\r\n                    </select>\r\n                </div>\r\n            </div>\r\n            <div class="control-group">\r\n                <label class="control-label" for="tagList">Tags</label>\r\n                <div class="controls">\r\n                    <input type="text" id="tagList" data-bind="value: tagListFormatted" placeholder="tag1,tag2" />\r\n                </div>\r\n            </div>\r\n            <div class="control-group">\r\n                <label class="control-label" for="owner">Owner</label>\r\n                <div class="controls">\r\n                    <input type="text" id="owner" data-bind="value: owner" />\r\n                </div>\r\n            </div>\r\n            <div class="control-group">\r\n                <label class="control-label" for="assignedTo">Assigned To</label>\r\n                <div class="controls">\r\n                    <input type="text" id="assignedTo" data-bind="value: assignedTo"\r\n                        placeholder="person name" />\r\n                </div>\r\n            </div>\r\n            <div class="control-group">\r\n                <div class="controls">\r\n                    <label class="checkbox" for="affectsCustomer">\r\n                        <input type="checkbox" id="affectsCustomer" data-bind="checked: affectsCustomer" />Affects Customer</label>\r\n                </div>\r\n            </div>\r\n\r\n        </div>\r\n\r\n        <div class="control-group">\r\n            <label class="control-label" for="description">Description</label>\r\n            <div class="controls">\r\n                <textarea id="description" style="width: 100%; min-height: 300px;"\r\n                    data-bind="value: details"\r\n                    placeholder="Enter description"></textarea>\r\n            </div>\r\n        </div>\r\n    </div>\r\n\r\n</section>\r\n';});

define('text!views/ticketlist.html',[],function () { return '<section id="tickets-view">\r\n    <header class="page-header">\r\n        <a class="btn btn-sm btn-primary pull-right"\r\n            data-bind="click: refresh" href="#"><i class="icon-refresh"></i>&nbsp;<span data-i18n="appuitext:generalRefresh" /></a>\r\n        <h1 data-bind="text: title"></h1>\r\n\r\n    </header>\r\n    <div>\r\n        <nav class="well well-sm">\r\n            <ul class="pager pagination pagination-sm col-md-12" style="display: block; margin: 0;">\r\n                <li class="previous" data-bind="css: { disabled: !canPrev() }">\r\n                    <a href="#" data-bind="click: previous, clickBubble: false"><i class="icon-chevron-left"></i>&nbsp;<span data-i18n="appuitext:pagerPrevious" /></a>\r\n                </li>\r\n                <li><small><i data-i18n="appuitext:pagerPage" />\r\n                    <!--ko text: currentPage -->\r\n                    <!--/ko-->\r\n                    <i data-i18n="appuitext:pagerOf" />\r\n                    <!--ko text: maxPage -->\r\n                    <!--/ko-->\r\n                    (<!-- ko text: rowCount --><!--/ko-->\r\n                    <i data-i18n="appuitext:pagerTotalTickets" />)</small></li>\r\n                <li class="next" data-bind="css: { disabled: !canNext() }">\r\n                    <a href="#" data-bind="click: next, clickBubble: false"><span data-i18n="appuitext:pagerNext" />&nbsp;<i class="icon-chevron-right"></i></a>\r\n                </li>\r\n            </ul>\r\n        </nav>\r\n        <section class="view-list" data-bind="template: { foreach: tickets, beforeRemove: hideTicketElement, afterAdd: showTicketElement, afterRender: ticketItemsRendered }">\r\n            <!--ko if: $index() != 0--><hr /><!--/ko-->\r\n            <article class="ticket-brief" title="Go to ticket details" data-bind="ticketChanged: lastUpdateDate">\r\n                <header class="row">\r\n                    <div class="col-md-7">\r\n                        <h4><span data-i18n="appmodeltext:ticketTicketId" />\r\n                            <!--ko text: ticketId -->\r\n                            <!--/ko-->\r\n                            <!--ko text:  $.i18n.t(\'appmodeltext:category\' + category()) -->\r\n                            <!--/ko-->\r\n                            <!--ko text:  $.i18n.t(\'appmodeltext:ticketType\' + ticketType())  -->\r\n                            <!--/ko-->\r\n                        </h4>\r\n                        <h5>\r\n                            <!--ko text: title -->\r\n                            <!--/ko-->\r\n                        </h5>\r\n                        <address>\r\n                            <div>\r\n                                <span data-i18n="appmodeltext:ticketOwner" />\r\n\r\n                                <!--ko text: owner || \'none\' -->\r\n                                <!--/ko-->\r\n                            </div>\r\n                            <div>\r\n                                <span data-i18n="appmodeltext:ticketAssignedTo" />\r\n                                <!--ko text: assignedTo() || \'unassigned\' -->\r\n                                <!--/ko-->\r\n                            </div>\r\n                        </address>\r\n\r\n                    </div>\r\n                    <div class="col-md-5">\r\n                        <div>\r\n                            <small>\r\n                                <!--ko text: $.i18n.t(\'appmodeltext:ticketStatus\' + ticketStatus()) -->\r\n                                <!--/ko-->\r\n                                -\r\n                                <!--ko text: $.i18n.t(\'appmodeltext:priority\' + priority()) -->\r\n                                <!--/ko-->\r\n                                <span data-i18n="appmodeltext:ticketPriority" />\r\n                            </small>\r\n                        </div>\r\n                        <div>\r\n                            <small>\r\n                                <!--ko text: createdCombined -->\r\n                                <!--/ko-->\r\n                            </small>\r\n                        </div>\r\n                        <div>\r\n                            <small>\r\n                                <!--ko text: lastUpdatedCombined -->\r\n                                <!--/ko-->\r\n                            </small>\r\n                        </div>\r\n                    </div>\r\n                </header>\r\n            </article>\r\n\r\n        </section>\r\n    </div>\r\n\r\n\r\n\r\n</section>\r\n';});

define('plugins/dialog',["durandal/system","durandal/app","durandal/composition","durandal/activator","durandal/viewEngine","jquery","knockout"],function(t,e,n,i,r,a,o){function s(e){return t.defer(function(n){t.isString(e)?t.acquire(e).then(function(e){n.resolve(t.resolveObject(e))}).fail(function(n){t.error("Failed to load dialog module ("+e+"). Details: "+n.message)}):n.resolve(e)}).promise()}var c,u={},l=0,d=function(t,e,n){this.message=t,this.title=e||d.defaultTitle,this.options=n||d.defaultOptions};return d.prototype.selectOption=function(t){c.close(this,t)},d.prototype.getView=function(){return r.processMarkup(d.defaultViewMarkup)},d.setViewUrl=function(t){delete d.prototype.getView,d.prototype.viewUrl=t},d.defaultTitle=e.title||"Application",d.defaultOptions=["Ok"],d.defaultViewMarkup=['<div data-view="plugins/messageBox" class="messageBox">','<div class="modal-header">','<h3 data-bind="text: title"></h3>',"</div>",'<div class="modal-body">','<p class="message" data-bind="text: message"></p>',"</div>",'<div class="modal-footer" data-bind="foreach: options">','<button class="btn" data-bind="click: function () { $parent.selectOption($data); }, text: $data, css: { \'btn-primary\': $index() == 0, autofocus: $index() == 0 }"></button>',"</div>","</div>"].join("\n"),c={MessageBox:d,currentZIndex:1050,getNextZIndex:function(){return++this.currentZIndex},isOpen:function(){return l>0},getContext:function(t){return u[t||"default"]},addContext:function(t,e){e.name=t,u[t]=e;var n="show"+t.substr(0,1).toUpperCase()+t.substr(1);this[n]=function(e,n){return this.show(e,n,t)}},createCompositionSettings:function(t,e){var n={model:t,activate:!1};return e.attached&&(n.attached=e.attached),e.compositionComplete&&(n.compositionComplete=e.compositionComplete),n},getDialog:function(t){return t?t.__dialog__:void 0},close:function(t){var e=this.getDialog(t);if(e){var n=Array.prototype.slice.call(arguments,1);e.close.apply(e,n)}},show:function(e,r,a){var o=this,c=u[a||"default"];return t.defer(function(t){s(e).then(function(e){var a=i.create();a.activateItem(e,r).then(function(i){if(i){var r=e.__dialog__={owner:e,context:c,activator:a,close:function(){var n=arguments;a.deactivateItem(e,!0).then(function(i){i&&(l--,c.removeHost(r),delete e.__dialog__,0==n.length?t.resolve():1==n.length?t.resolve(n[0]):t.resolve.apply(t,n))})}};r.settings=o.createCompositionSettings(e,c),c.addHost(r),l++,n.compose(r.host,r.settings)}else t.resolve(!1)})})}).promise()},showMessage:function(e,n,i){return t.isString(this.MessageBox)?c.show(this.MessageBox,[e,n||d.defaultTitle,i||d.defaultOptions]):c.show(new this.MessageBox(e,n,i))},install:function(t){e.showDialog=function(t,e,n){return c.show(t,e,n)},e.showMessage=function(t,e,n){return c.showMessage(t,e,n)},t.messageBox&&(c.MessageBox=t.messageBox),t.messageBoxView&&(c.MessageBox.prototype.getView=function(){return t.messageBoxView})}},c.addContext("default",{blockoutOpacity:.2,removeDelay:200,addHost:function(t){var e=a("body"),n=a('<div class="modalBlockout"></div>').css({"z-index":c.getNextZIndex(),opacity:this.blockoutOpacity}).appendTo(e),i=a('<div class="modalHost"></div>').css({"z-index":c.getNextZIndex()}).appendTo(e);if(t.host=i.get(0),t.blockout=n.get(0),!c.isOpen()){t.oldBodyMarginRight=e.css("margin-right"),t.oldInlineMarginRight=e.get(0).style.marginRight;var r=a("html"),o=e.outerWidth(!0),s=r.scrollTop();a("html").css("overflow-y","hidden");var u=a("body").outerWidth(!0);e.css("margin-right",u-o+parseInt(t.oldBodyMarginRight)+"px"),r.scrollTop(s)}},removeHost:function(t){if(a(t.host).css("opacity",0),a(t.blockout).css("opacity",0),setTimeout(function(){o.removeNode(t.host),o.removeNode(t.blockout)},this.removeDelay),!c.isOpen()){var e=a("html"),n=e.scrollTop();e.css("overflow-y","").scrollTop(n),t.oldInlineMarginRight?a("body").css("margin-right",t.oldBodyMarginRight):a("body").css("margin-right","")}},compositionComplete:function(t,e,n){var i=a(t),r=i.width(),o=i.height(),s=c.getDialog(n.model);i.css({"margin-top":(-o/2).toString()+"px","margin-left":(-r/2).toString()+"px"}),a(s.host).css("opacity",1),a(t).hasClass("autoclose")&&a(s.blockout).click(function(){s.close()}),a(".autofocus",t).each(function(){a(this).focus()})}}),c});
define('plugins/http',["jquery","knockout"],function(t,e){return{callbackParam:"callback",get:function(e,n){return t.ajax(e,{data:n})},jsonp:function(e,n,i){return-1==e.indexOf("=?")&&(i=i||this.callbackParam,e+=-1==e.indexOf("?")?"?":"&",e+=i+"=?"),t.ajax({url:e,dataType:"jsonp",data:n})},post:function(n,i){return t.ajax({url:n,data:e.toJSON(i),type:"POST",contentType:"application/json",dataType:"json"})}}});
define('plugins/observable',["durandal/system","durandal/binder","knockout"],function(t,e,n){function i(t){var e=t[0];return"_"===e||"$"===e}function r(e){if(!e||t.isElement(e)||e.ko===n||e.jquery)return!1;var i=d.call(e);return-1==f.indexOf(i)&&!(e===!0||e===!1)}function a(t,e){var n=t.__observable__,i=!0;if(!n||!n.__full__){n=n||(t.__observable__={}),n.__full__=!0,v.forEach(function(n){t[n]=function(){i=!1;var t=h[n].apply(e,arguments);return i=!0,t}}),g.forEach(function(n){t[n]=function(){i&&e.valueWillMutate();var r=m[n].apply(t,arguments);return i&&e.valueHasMutated(),r}}),p.forEach(function(n){t[n]=function(){for(var r=0,a=arguments.length;a>r;r++)o(arguments[r]);i&&e.valueWillMutate();var s=m[n].apply(t,arguments);return i&&e.valueHasMutated(),s}}),t.splice=function(){for(var n=2,r=arguments.length;r>n;n++)o(arguments[n]);i&&e.valueWillMutate();var a=m.splice.apply(t,arguments);return i&&e.valueHasMutated(),a};for(var r=0,a=t.length;a>r;r++)o(t[r])}}function o(e){var o,s;if(r(e)&&(o=e.__observable__,!o||!o.__full__)){if(o=o||(e.__observable__={}),o.__full__=!0,t.isArray(e)){var u=n.observableArray(e);a(e,u)}else for(var l in e)i(l)||o[l]||(s=e[l],t.isFunction(s)||c(e,l,s));b&&t.log("Converted",e)}}function s(t,e,n){var i;t(e),i=t.peek(),n?i.destroyAll||(i||(i=[],t(i)),a(i,t)):o(i)}function c(e,i,r){var c,u,l=e.__observable__||(e.__observable__={});if(void 0===r&&(r=e[i]),t.isArray(r))c=n.observableArray(r),a(r,c),u=!0;else if("function"==typeof r){if(!n.isObservable(r))return null;c=r}else t.isPromise(r)?(c=n.observable(),r.then(function(e){if(t.isArray(e)){var i=n.observableArray(e);a(e,i),e=i}c(e)})):(c=n.observable(r),o(r));return Object.defineProperty(e,i,{configurable:!0,enumerable:!0,get:c,set:n.isWriteableObservable(c)?function(e){e&&t.isPromise(e)?e.then(function(e){s(c,e,t.isArray(e))}):s(c,e,u)}:void 0}),l[i]=c,c}function u(e,n,i){var r,a=this,o={owner:e,deferEvaluation:!0};return"function"==typeof i?o.read=i:("value"in i&&t.error('For ko.defineProperty, you must not specify a "value" for the property. You must provide a "get" function.'),"function"!=typeof i.get&&t.error('For ko.defineProperty, the third parameter must be either an evaluator function, or an options object containing a function called "get".'),o.read=i.get,o.write=i.set),r=a.computed(o),e[n]=r,c(e,n,r)}var l,d=Object.prototype.toString,f=["[object Function]","[object String]","[object Boolean]","[object Number]","[object Date]","[object RegExp]"],v=["remove","removeAll","destroy","destroyAll","replace"],g=["pop","reverse","sort","shift","splice"],p=["push","unshift"],m=Array.prototype,h=n.observableArray.fn,b=!1;return l=function(t,e){var i,r,a;return t?(i=t.__observable__,i&&(r=i[e])?r:(a=t[e],n.isObservable(a)?a:c(t,e,a))):null},l.defineProperty=u,l.convertProperty=c,l.convertObject=o,l.install=function(t){var n=e.binding;e.binding=function(t,e,i){i.applyBindings&&!i.skipConversion&&o(t),n(t,e)},b=t.logConversion},l});
define('plugins/serializer',["durandal/system"],function(t){return{typeAttribute:"type",space:void 0,replacer:function(t,e){if(t){var n=t[0];if("_"===n||"$"===n)return void 0}return e},serialize:function(e,n){return n=void 0===n?{}:n,(t.isString(n)||t.isNumber(n))&&(n={space:n}),JSON.stringify(e,n.replacer||this.replacer,n.space||this.space)},getTypeId:function(t){return t?t[this.typeAttribute]:void 0},typeMap:{},registerType:function(){var e=arguments[0];if(1==arguments.length){var n=e[this.typeAttribute]||t.getModuleId(e);this.typeMap[n]=e}else this.typeMap[e]=arguments[1]},reviver:function(t,e,n,i){var r=n(e);if(r){var a=i(r);if(a)return a.fromJSON?a.fromJSON(e):new a(e)}return e},deserialize:function(t,e){var n=this;e=e||{};var i=e.getTypeId||function(t){return n.getTypeId(t)},r=e.getConstructor||function(t){return n.typeMap[t]},a=e.reviver||function(t,e){return n.reviver(t,e,i,r)};return JSON.parse(t,a)}}});
define('plugins/widget',["durandal/system","durandal/composition","jquery","knockout"],function(t,e,n,i){function r(t,n){var r=i.utils.domData.get(t,c);r||(r={parts:e.cloneNodes(i.virtualElements.childNodes(t))},i.virtualElements.emptyNode(t),i.utils.domData.set(t,c,r)),n.parts=r.parts}var a={},o={},s=["model","view","kind"],c="durandal-widget-data",u={getSettings:function(e){var n=i.utils.unwrapObservable(e())||{};if(t.isString(n))return{kind:n};for(var r in n)n[r]=-1!=i.utils.arrayIndexOf(s,r)?i.utils.unwrapObservable(n[r]):n[r];return n},registerKind:function(t){i.bindingHandlers[t]={init:function(){return{controlsDescendantBindings:!0}},update:function(e,n,i,a,o){var s=u.getSettings(n);s.kind=t,r(e,s),u.create(e,s,o,!0)}},i.virtualElements.allowedBindings[t]=!0},mapKind:function(t,e,n){e&&(o[t]=e),n&&(a[t]=n)},mapKindToModuleId:function(t){return a[t]||u.convertKindToModulePath(t)},convertKindToModulePath:function(t){return"widgets/"+t+"/viewmodel"},mapKindToViewId:function(t){return o[t]||u.convertKindToViewPath(t)},convertKindToViewPath:function(t){return"widgets/"+t+"/view"},createCompositionSettings:function(t,e){return e.model||(e.model=this.mapKindToModuleId(e.kind)),e.view||(e.view=this.mapKindToViewId(e.kind)),e.preserveContext=!0,e.activate=!0,e.activationData=e,e.mode="templated",e},create:function(t,n,i,r){r||(n=u.getSettings(function(){return n},t));var a=u.createCompositionSettings(t,n);e.compose(t,a,i)},install:function(t){if(t.bindingName=t.bindingName||"widget",t.kinds)for(var e=t.kinds,n=0;n<e.length;n++)u.registerKind(e[n]);i.bindingHandlers[t.bindingName]={init:function(){return{controlsDescendantBindings:!0}},update:function(t,e,n,i,a){var o=u.getSettings(e);r(t,o),u.create(t,o,a,!0)}},i.virtualElements.allowedBindings[t.bindingName]=!0}};return u});
define('transitions/entrance',["durandal/system","durandal/composition","jquery"],function(e,t,n){var i=100,r={marginRight:0,marginLeft:0,opacity:1},a={marginLeft:"",marginRight:"",opacity:"",display:""},o=function(t){return e.defer(function(e){function o(){e.resolve()}function s(){t.keepScrollPosition||n(document).scrollTop(0)}function c(){s(),t.triggerAttach();var e={marginLeft:l?"0":"20px",marginRight:l?"0":"-20px",opacity:0,display:"block"},i=n(t.child);i.css(e),i.animate(r,u,"swing",function(){i.css(a),o()})}if(t.child){var u=t.duration||500,l=!!t.fadeOnly;t.activeView?n(t.activeView).fadeOut(i,c):c()}else n(t.activeView).fadeOut(i,o)}).promise()};return o});
require(["main"]);
}());